#################################################################################################
###############       INSTITUTO NACIONAL DE ESTADISTICA Y CENSOS - INEC           ###############
###############              DIRECCION DE ESTADISTICAS ECONOMICAS                 ###############
###############          DIRECTORIO DE EMPRESAS Y ESTABLECIMIENTOS - DIEE         ###############
###############                                                                   ###############
############### TABULADOS DEL DIRECTORIO DE EMPRESAS Y ESTABLECIMIENTOS, ANIO 2021 ###############           
#################################################################################################
#Elaborada 25-10-2019.
#Actualizado 24-08-2020
#Actualizada 15-10-2020
#Actualizado 20-08-2021
#Actualizado 17-08-2022
#Actualizado 12-10-2022
#Actualizado 10-12-2022

#Requerimientos##################################################################################
#Es necesario crear un proyecto dentro del mismo deberan estar los siguientes archivos:
#FORMATO SPSS: BASES DE DATOS PUBLICADAS: "EMPRESAS2021_periodo_2006_2011"
#                                         "EMPRESAS2021_periodo_2012_2021"
#FORMATO EXCEL: CATALOGO : "diee_catalogo"
#               PLANTILLA EN BLANCO: "Tabulados_DIEE_2021"
#FORMATO R : SCRIPT_TABULADOS_DIEE_2021
#################################################################################################

#librerias y paquetes#
library(dplyr)
library(openxlsx)
library(reshape2)
library(foreign)
library(data.table)
library(writexl)
install.packages("zipR")
# Limpiar objetos de ser necesario
rm(list = ls()) #Borra objetos

####################################### BASE DE DATOS ##########################################
#Aumentar la capacidad de almacenamiento
memory.limit(size=56000)

#Lectura de la base de datos.
######BASE DE DATOS 2012_2021###################
bd_diee <- read.spss("EMPRESAS2021_periodo_2012_2021.sav",use.value.labels=F,to.data.frame = T)
######BASE DE DATOS 2006_2011
bd_diee2 <- read.spss("EMPRESAS2021_periodo_2006_2011.sav",use.value.labels=F,to.data.frame = T)
bd_diee1 <- bd_diee2 %>% filter(situacion==1)

#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )

###########Formato / color####################
newStyle <- createStyle(fgFill = "#FFFFFF") #blanco
grisStyle <- createStyle(fgFill = "#D9D9D9") #gris

####################################### FUNCIONES ##############################################

#########1.1 SECCIÓN I: número de empresas##################

################TABULADO 1.1.1###############################
###EMPRESAS SEGÚN PARTICIPACIÓN NACIONAL,             ###
###AÑO 2021 POR ESTRUCTURA PARA ESTRATIFICACION       ###

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_estrato <- bd_dieeact %>% group_by(estructura_estrat) %>% summarise("total_estrato"=n(),porcentaje = 0)
total <- as.numeric(sum(t_estrato$total_estrato,na.rm =T ))
t_estrato$porcentaje <- t_estrato$total_estrato / total

#Lectura catalogo de variables.
des_estrato <- read.xlsx("diee_catologo.xlsx", sheet = "estructura_estratificacion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_estrato,t_estrato,by.x = "CODIGO",by.y = "estructura_estrat",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_estrato,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb1,sheet = "1.1.1.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb1,sheet = "1.1.1.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb1,sheet = "1.1.1.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb1,sheet = "1.1.1.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb1,"1.1.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb1,"1.1.1.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado1 <- saveWorkbook(wb1,"Tabulados_DIEE_2021.xlsx",overwrite = T)

rm(wb1)

####################TABULADO 1.1.2 ##################################
###TOTAL EMPRESAS (UNIVERSO DIEE), PERIODO 2012 - 2021 POR ANO###	

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee %>% filter(situacion==1 )
#Total empresas del anio 2012-2021
total_anios <- bd_dieeact %>% group_by(anio) %>% summarise("total_anios"=n())

#Exportar resultados a excel
wb2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb2,sheet = "1.1.2.",total_anios, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb2,"1.1.2.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb2,"1.1.2.",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado2 <- saveWorkbook(wb2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

rm(wb2)

#####################TABULADO 1.1.3###################################
#EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021#
#               POR FORMA INSTITUCIONAL 	                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(forma_institucional,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieefi <- df1 %>% filter(anio == 2021 & situacion==1 )

#calculo de las variables
t_formainstitucional <- bd_dieefi %>% group_by(forma_institucional) %>% summarise("total_formainstitucional"=n(),porcentaje = 0)
total <- sum(t_formainstitucional$total_formainstitucional,na.rm =T )
t_formainstitucional$porcentaje <- t_formainstitucional$total_formainstitucional / total

#Lectura catalogo de variables.
des_formainstitucional <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_formainstitucional,t_formainstitucional,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_formainstitucional,porcentaje)
t_estrato2 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb3<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3,sheet = "1.1.3.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb3,sheet = "1.1.3.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb3,sheet = "1.1.3.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb3,sheet = "1.1.3.",t_estrato2,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb3,"1.1.3.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3,"1.1.3.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3 <- saveWorkbook(wb3,"Tabulados_DIEE_2021.xlsx",overwrite = T)

rm(wb3)

#########################TABULADO 1.1.4#################################
#EMPRESAS SEGUNN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021##
#                    POR TAMANO DE EMPRESA                         #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamanoe_plazas,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamano <- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise("total_tamano"=n(),porcentaje = 0)
total <- sum(t_tamano$total_tamano,na.rm =T )
t_tamano$porcentaje <- t_tamano$total_tamano / total

#Lectura catalogo de variables.
des_tamano <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamano,t_tamano,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_tamano,porcentaje)
t_estrato3 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb4<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb4,sheet = "1.1.4.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb4,sheet = "1.1.4.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb4,sheet = "1.1.4.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb4,sheet = "1.1.4.",t_estrato3,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb4,"1.1.4.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb4,"1.1.4.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb4,"1.1.4.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado4 <- saveWorkbook(wb4,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb4)
rm(des_tamano)
rm(dft3)
rm(dft2)

#########################TABULADO 1.1.5#################################
#EMPRESAS SEGUNN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021##
#                    POR TAMANO DE EMPRESA  (COP)               #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamano_cop,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamano1 <- bd_dieeact %>% group_by(tamano_cop) %>% summarise("total_tamano"=n(),porcentaje = 0)
total <- sum(t_tamano1$total_tamano,na.rm =T )
t_tamano1$porcentaje <- t_tamano1$total_tamano / total

#Lectura catalogo de variables.
des_tamano1 <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamano1,t_tamano1,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_tamano,porcentaje)
t_estrato4 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb5<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb5,sheet = "1.1.5.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb5,sheet = "1.1.5.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb5,sheet = "1.1.5.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb5,sheet = "1.1.5.",t_estrato4,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb5,"1.1.5.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb5,"1.1.5.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb5,"1.1.5.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado5 <- saveWorkbook(wb5,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb5)

#########################TABULADO 1.1.6#################################
# EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021 #
#                    POR SECTOR ECONOMICO                          #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_sectores <- bd_dieeact %>% group_by(gsectores) %>% summarise("total_sectores"=n(),porcentaje = 0)
total <- sum(t_sectores$total_sectores,na.rm =T )
t_sectores$porcentaje <- t_sectores$total_sectores / total

#Lectura catalogo de variables.
des_sectores <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectores,t_sectores,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_sectores,porcentaje)
t_estrato4 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb6<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb6,sheet = "1.1.6.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb6,sheet = "1.1.6.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb6,sheet = "1.1.6.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb6,sheet = "1.1.6.",t_estrato4,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb6,"1.1.6.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb6,"1.1.6.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado6 <- saveWorkbook(wb6,"Tabulados_DIEE_2021.xlsx",overwrite = T)

rm(wb6)

#########################TABULADO 1.1.7#################################
#  EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021#
#                POR ACTIVIDAD ECONOMICA                           #  

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_seccion <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise("total_seccion"=n(),porcentaje = 0)
total <- sum(t_seccion$total_seccion,na.rm =T )
t_seccion$porcentaje <- t_seccion$total_seccion / total

#Lectura catalogo de variables.
des_seccion <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccion,t_seccion,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_seccion,porcentaje)
t_estrato5 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb7<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb7,sheet = "1.1.7.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb7,sheet = "1.1.7.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb7,sheet = "1.1.7.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb7,sheet = "1.1.7.",t_estrato5,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb7,"1.1.7.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb7,"1.1.7.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado7 <- saveWorkbook(wb7,"Tabulados_DIEE_2021.xlsx",overwrite = T)

rm(wb7)

#########################TABULADO 1.1.8################################
# EMPRESAS SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021#
#                     POR PROVINCIA                               #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_provincia <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise("total_provincia"=n(),porcentaje = 0)
total <- sum(t_provincia$total_provincia,na.rm =T )
t_provincia$porcentaje <- t_provincia$total_provincia / total

##lectura de excel para llenar###
des_provincia <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provincia,t_provincia,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_provincia,porcentaje)
t_estrato6 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb8<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb8,sheet = "1.1.8.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb8,sheet = "1.1.8.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb8,sheet = "1.1.8.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb8,sheet = "1.1.8.",t_estrato6,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb8,"1.1.8.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb8,"1.1.8.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado8 <- saveWorkbook(wb8,"Tabulados_DIEE_2021.xlsx",overwrite = T)

rm(wb8)

#########1.2 SECCIÓN II: ventas##################

###################TABULADO 1.2.1###############################
#      VENTAS TOTALES (UNIVERSO DIEE), PERIODO 2009 - 2021 #
#                   POR ANIO                               #

# Lectura de base 2009-2011

bd_dieeventas <- bd_diee1 %>% select(ventas_totales,anio,situacion,exportaciones_netas,ventas_nacionales)
d_dieeven <- bd_dieeventas %>% filter (anio != 2006 & anio != 2007 & anio != 2008)

#VENTAS TOTALES#
#Total empresas del año 2009-2011#
t_ventas1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb9<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb9,sheet = "1.2.1.",t_ventas1, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado9 <- saveWorkbook(wb9,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#VENTAS NACIONALES#
#total empresas del a?o 2009 - 2011#
t_vntanacional1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
t_vntanacional2 <- t_vntanacional1 %>% select(total_ventanacional)

#Exportar resultados a excel
wb92<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb92,sheet = "1.2.1.",t_vntanacional2, startCol = 3,startRow = 7,colNames = F) ##escribir
tabulado92 <- saveWorkbook(wb92,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#EXPORTACIONES#
#total empresas del a?o 2009 - 2011#
t_exportaciones1 <- d_dieeven %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
t_exportaciones2 <- t_exportaciones1 %>% select(total_exportaciones)

#Exportar resultados a excel
wb93<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb93,sheet = "1.2.1.",t_exportaciones2, startCol = 4,startRow = 7,colNames = F) ##escribir
tabulado93 <- saveWorkbook(wb93,"Tabulados_DIEE_2021.xlsx",overwrite = T)
                          
#Lectura de la base de datos 2012-2021
bd_diee2 <- bd_diee %>% select(ventas_totales,anio,situacion,exportaciones_netas,ventas_nacionales)
bd_dieeac2 <- bd_diee2 %>% filter (situacion == 1)

#Total empresas del año 2012-2021
t_ventas2 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb91<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb91,sheet = "1.2.1.",t_ventas2, startCol = 1,startRow = 10,colNames = F) ##escribir
addStyle(wb91,"1.2.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb91,"1.2.1.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado91 <- saveWorkbook(wb91,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#VENTAS NACIONALES#
#total empresas del a?o 2012 - 2021#
t_vntanacional11 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
t_vntanacional22 <- t_vntanacional11 %>% select(total_ventanacional)

#Exportar resultados a excel
wb922<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb922,sheet = "1.2.1.",t_vntanacional22, startCol = 3,startRow = 10,colNames = F) ##escribir
tabulado922 <- saveWorkbook(wb922,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#EXPORTACIONES#
#total empresas del a?o 2012 - 2021#
t_exportaciones11 <- bd_dieeac2 %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
t_exportaciones22 <- t_exportaciones11 %>% select(total_exportaciones)

#Exportar resultados a excel
wb933<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb933,sheet = "1.2.1.",t_exportaciones22, startCol = 4,startRow = 10,colNames = F) ##escribir
addStyle(wb933,"1.2.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb933,"1.2.1.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado933 <- saveWorkbook(wb933,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###############TABULADO 1.2.2 (CONSTANTES)#########################
###VENTAS TOTALES (UNIVERSO DIEE), PERIODO 2009 - 2021 POR ANIO

#lectura de base 2009
bd_dieeventas3 <- bd_diee1 %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven3 <- bd_dieeventas3 %>% filter (anio == 2009 )
t_ventas2009 <- d_dieeven3 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/114.593630834947)*100,na.rm=T))

#Exportar resultados a excel
wb10<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb10,sheet = "1.2.2.",t_ventas2009, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado10 <- saveWorkbook(wb10,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2009 <- d_dieeven3 %>% summarise ("total_ventas"=sum((ventas_nacionales/114.593630834947)*100,na.rm=T))
    t_ventanacional09<- t_ventanacional2009 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_1,sheet = "1.2.2.",t_ventanacional09, startCol = 3,startRow = 7,colNames = F) ##escribir
    tabulado10_1 <- saveWorkbook(wb10_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2009 <- d_dieeven3 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/114.593630834947)*100,na.rm=T))
    t_exportaciones09<- t_exportaciones2009 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_2,sheet = "1.2.2.",t_exportaciones09, startCol = 4,startRow = 7,colNames = F) ##escribir
    tabulado10_2 <- saveWorkbook(wb10_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)


#lectura de base 2010
bd_dieeventas4 <- bd_diee1 %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven4 <- bd_dieeventas4 %>% filter (anio == 2010 & situacion == 1)
t_ventas2010 <- d_dieeven4 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/123.148137016917)*100,na.rm=T))

#Exportar resultados a excel
wb101<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb101,sheet = "1.2.2.",t_ventas2010, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado101 <- saveWorkbook(wb101,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2010 <- d_dieeven4 %>% summarise ("total_ventas"=sum((ventas_nacionales/123.148137016917)*100,na.rm=T))
    t_ventanacional10<- t_ventanacional2010 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_11<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_11,sheet = "1.2.2.",t_ventanacional10, startCol = 3,startRow = 8,colNames = F) ##escribir
    tabulado10_11 <- saveWorkbook(wb10_11,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2010 <- d_dieeven4 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/123.148137016917)*100,na.rm=T))
    t_exportaciones10<- t_exportaciones2010 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_12<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_12,sheet = "1.2.2.",t_exportaciones10, startCol = 4,startRow = 8,colNames = F) ##escribir
    tabulado10_12 <- saveWorkbook(wb10_12,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2011
bd_dieeventas5 <- bd_diee1 %>% select(ventas_totales,anio,situacion, ventas_nacionales,exportaciones_netas)
d_dieeven5 <- bd_dieeventas5 %>% filter (anio == 2011 & situacion == 1)
t_ventas2011 <- d_dieeven5 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/130.12159330682)*100,na.rm=T))

#Exportar resultados a excel
wb102<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb102,sheet = "1.2.2.",t_ventas2011, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado102 <- saveWorkbook(wb102,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2011 <- d_dieeven5 %>% summarise ("total_ventas"=sum((ventas_nacionales/130.12159330682)*100,na.rm=T))
    t_ventanacional11<- t_ventanacional2011 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_21<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_21,sheet = "1.2.2.",t_ventanacional11, startCol = 3,startRow = 9,colNames = F) ##escribir
    tabulado10_21 <- saveWorkbook(wb10_21,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2011 <- d_dieeven5 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/130.12159330682)*100,na.rm=T))
    t_exportaciones11<- t_exportaciones2011 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_22<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_22,sheet = "1.2.2.",t_exportaciones11, startCol = 4,startRow = 9,colNames = F) ##escribir
    tabulado10_22 <- saveWorkbook(wb10_22,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2012
bd_dieeventas6 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven6 <- bd_dieeventas6 %>% filter (anio == 2012 & situacion == 1)
t_ventas2012 <- d_dieeven6 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/136.608484020484)*100,na.rm=T))

#Exportar resultados a excel
wb103<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb103,sheet = "1.2.2.",t_ventas2012, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado103 <- saveWorkbook(wb103,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2012 <- d_dieeven6 %>% summarise ("total_ventas"=sum((ventas_nacionales/136.608484020484)*100,na.rm=T))
    t_ventanacional12<- t_ventanacional2012 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_31<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_31,sheet = "1.2.2.",t_ventanacional12, startCol = 3,startRow = 10,colNames = F) ##escribir
    tabulado10_31 <- saveWorkbook(wb10_31,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2012 <- d_dieeven6 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/136.608484020484)*100,na.rm=T))
    t_exportaciones12<- t_exportaciones2012 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_32<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_32,sheet = "1.2.2.",t_exportaciones12, startCol = 4,startRow = 10,colNames = F) ##escribir
    tabulado10_32 <- saveWorkbook(wb10_32,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2013
bd_dieeventas7 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven7 <- bd_dieeventas7 %>% filter (anio == 2013 & situacion == 1)
t_ventas2013 <- d_dieeven7 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/140.836583556647)*100,na.rm=T))

#Exportar resultados a excel
wb104<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb104,sheet = "1.2.2.",t_ventas2013, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado104 <- saveWorkbook(wb104,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2013 <- d_dieeven7 %>% summarise ("total_ventas"=sum((ventas_nacionales/140.836583556647)*100,na.rm=T))
    t_ventanacional13<- t_ventanacional2013 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_41<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_41,sheet = "1.2.2.",t_ventanacional13, startCol = 3,startRow = 11,colNames = F) ##escribir
    tabulado10_41 <- saveWorkbook(wb10_41,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2013 <- d_dieeven7 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/140.836583556647)*100,na.rm=T))
    t_exportaciones13<- t_exportaciones2013 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_42<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_42,sheet = "1.2.2.",t_exportaciones13, startCol = 4,startRow = 11,colNames = F) ##escribir
    tabulado10_42 <- saveWorkbook(wb10_42,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2014
bd_dieeventas8 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven8 <- bd_dieeventas8 %>% filter (anio == 2014 & situacion == 1)
t_ventas2014 <- d_dieeven8 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/145.104922216934)*100,na.rm=T))

#Exportar resultados a excel
wb105<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb105,sheet = "1.2.2.",t_ventas2014, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado105 <- saveWorkbook(wb105,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2014 <- d_dieeven8 %>% summarise ("total_ventas"=sum((ventas_nacionales/145.104922216934)*100,na.rm=T))
    t_ventanacional14<- t_ventanacional2014 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_51<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_51,sheet = "1.2.2.",t_ventanacional14, startCol = 3,startRow = 12,colNames = F) ##escribir
    tabulado10_51 <- saveWorkbook(wb10_51,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2014 <- d_dieeven8 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/145.104922216934)*100,na.rm=T))
    t_exportaciones14<- t_exportaciones2014 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_52<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_52,sheet = "1.2.2.",t_exportaciones14, startCol = 4,startRow = 12,colNames = F) ##escribir
    tabulado10_52 <- saveWorkbook(wb10_52,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2015
bd_dieeventas9 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven9 <- bd_dieeventas9 %>% filter (anio == 2015 & situacion == 1)
t_ventas2015 <- d_dieeven9 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/141.490328484162)*100,na.rm=T))

#Exportar resultados a excel
wb106<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb106,sheet = "1.2.2.",t_ventas2015, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado106 <- saveWorkbook(wb106,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2015 <- d_dieeven9 %>% summarise ("total_ventas"=sum((ventas_nacionales/141.490328484162)*100,na.rm=T))
    t_ventanacional15<- t_ventanacional2015 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_61<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_61,sheet = "1.2.2.",t_ventanacional15, startCol = 3,startRow = 13,colNames = F) ##escribir
    tabulado10_61 <- saveWorkbook(wb10_61,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2015 <- d_dieeven9 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/141.490328484162)*100,na.rm=T))
    t_exportaciones15<- t_exportaciones2015 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_62<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_62,sheet = "1.2.2.",t_exportaciones15, startCol = 4,startRow = 13,colNames = F) ##escribir
    tabulado10_62 <- saveWorkbook(wb10_62,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2016
bd_dieeventas10 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven10 <- bd_dieeventas10 %>% filter (anio == 2016 & situacion == 1)
t_ventas2016 <- d_dieeven10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/144.180974753378)*100,na.rm=T))

#Exportar resultados a excel
wb107<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb107,sheet = "1.2.2.",t_ventas2016, startCol = 1,startRow = 14,colNames = F) ##escribir
tabulado107 <- saveWorkbook(wb107,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2016 <- d_dieeven10 %>% summarise ("total_ventas"=sum((ventas_nacionales/144.180974753378)*100,na.rm=T))
    t_ventanacional16<- t_ventanacional2016 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_71<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_71,sheet = "1.2.2.",t_ventanacional16, startCol = 3,startRow = 14,colNames = F) ##escribir
    tabulado10_71 <- saveWorkbook(wb10_71,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2016 <- d_dieeven10 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/144.180974753378)*100,na.rm=T))
    t_exportaciones16<- t_exportaciones2016 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_72<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_72,sheet = "1.2.2.",t_exportaciones16, startCol = 4,startRow = 14,colNames = F) ##escribir
    tabulado10_72 <- saveWorkbook(wb10_72,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2017
bd_dieeventas101 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven10 <- bd_dieeventas101 %>% filter (anio == 2017 & situacion == 1)
t_ventas2017 <- d_dieeven10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/146.987310714795)*100,na.rm=T))

#Exportar resultados a excel
wb1071<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb1071,sheet = "1.2.2.",t_ventas2017, startCol = 1,startRow = 15,colNames = F) ##escribir
tabulado107 <- saveWorkbook(wb1071,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2017 <- d_dieeven10 %>% summarise ("total_ventas"=sum((ventas_nacionales/146.987310714795)*100,na.rm=T))
    t_ventanacional17<- t_ventanacional2017 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_711<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_711,sheet = "1.2.2.",t_ventanacional17, startCol = 3,startRow = 15,colNames = F) ##escribir
    tabulado10_711 <- saveWorkbook(wb10_711,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2017 <- d_dieeven10 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/146.987310714795)*100,na.rm=T))
    t_exportaciones17 <- t_exportaciones2017 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_722<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_722,sheet = "1.2.2.",t_exportaciones17, startCol = 4,startRow = 15,colNames = F) ##escribir
    tabulado10_722 <- saveWorkbook(wb10_722,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2018
bd_dieeventas11 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven11 <- bd_dieeventas11 %>% filter (anio == 2018 & situacion == 1)
t_ventas2018 <- d_dieeven11 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.660824062251)*100,na.rm=T))

#Exportar resultados a excel
wb108<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb108,sheet = "1.2.2.",t_ventas2018, startCol = 1,startRow = 16,colNames = F) ##escribir
tabulado108 <- saveWorkbook(wb108,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2018 <- d_dieeven11 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.660824062251)*100,na.rm=T))
    t_ventanacional18<- t_ventanacional2018 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_81<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_81,sheet = "1.2.2.",t_ventanacional18, startCol = 3,startRow = 16,colNames = F) ##escribir
    tabulado10_81 <- saveWorkbook(wb10_81,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2018 <- d_dieeven11 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.660824062251)*100,na.rm=T))
    t_exportaciones18 <- t_exportaciones2018 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_82<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_82,sheet = "1.2.2.",t_exportaciones18, startCol = 4,startRow = 16,colNames = F) ##escribir
    tabulado10_82 <- saveWorkbook(wb10_82,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2019
bd_dieeventas12 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_dieeven12 <- bd_dieeventas12 %>% filter (anio == 2019 & situacion == 1)
t_ventas2019 <- d_dieeven12 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/150.402318656309)*100,na.rm=T))

#Exportar resultados a excel
wb109<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb109,sheet = "1.2.2.",t_ventas2019, startCol = 1,startRow = 17,colNames = F) ##escribir
addStyle(wb109,"1.2.2.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb109,"1.2.2.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado109 <- saveWorkbook(wb109,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_ventanacional2019 <- d_dieeven12 %>% summarise ("total_ventas"=sum((ventas_nacionales/150.402318656309)*100,na.rm=T))
    t_ventanacional19 <- t_ventanacional2019 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_91<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_91,sheet = "1.2.2.",t_ventanacional19, startCol = 3,startRow = 17,colNames = F) ##escribir
    tabulado10_91 <- saveWorkbook(wb10_91,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2019 <- d_dieeven12 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/150.402318656309)*100,na.rm=T))
    t_exportaciones19 <- t_exportaciones2019 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_92<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_92,sheet = "1.2.2.",t_exportaciones19, startCol = 4,startRow = 17,colNames = F) ##escribir
    tabulado10_92 <- saveWorkbook(wb10_92,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###lectura de base 2020###
    bd_dieeventas13 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
    d_dieeven13 <- bd_dieeventas13 %>% filter (anio == 2020 & situacion == 1)
    t_ventas2020 <- d_dieeven13 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.802064061692)*100,na.rm=T))
    
    #Exportar resultados a excel
    wb1010<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb1010,sheet = "1.2.2.",t_ventas2020, startCol = 1,startRow = 18,colNames = F) ##escribir
    tabulado1010 <- saveWorkbook(wb1010,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #VENTAS NACIONALES#
    t_ventanacional2020 <- d_dieeven13 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.802064061692)*100,na.rm=T))
    t_ventanacional20 <- t_ventanacional2020 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_10<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_10,sheet = "1.2.2.",t_ventanacional20, startCol = 3,startRow = 18,colNames = F) ##escribir
    tabulado10_10 <- saveWorkbook(wb10_10,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2020 <- d_dieeven13 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.802064061692)*100,na.rm=T))
    t_exportaciones20 <- t_exportaciones2020 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_1_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_1_1,sheet = "1.2.2.",t_exportaciones20, startCol = 4,startRow = 18,colNames = F) ##escribir
    tabulado10_1_1 <- saveWorkbook(wb10_1_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###lectura de base 2021###
    bd_dieeventas14 <- bd_diee %>% select(ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
    d_dieeven14 <- bd_dieeventas14 %>% filter (anio == 2021 & situacion == 1)
    t_ventas2021 <- d_dieeven14 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/153.665955040775)*100,na.rm=T))
    
    #Exportar resultados a excel
    wb1011<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb1011,sheet = "1.2.2.",t_ventas2021, startCol = 1,startRow = 19,colNames = F) ##escribir
    tabulado1011 <- saveWorkbook(wb1011,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #VENTAS NACIONALES#
    t_ventanacional2021 <- d_dieeven14 %>% summarise ("total_ventas"=sum((ventas_nacionales/153.665955040775)*100,na.rm=T))
    t_ventanacional21 <- t_ventanacional2021 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb10_11<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_11,sheet = "1.2.2.",t_ventanacional21, startCol = 3,startRow = 19,colNames = F) ##escribir
    tabulado10_11 <- saveWorkbook(wb10_11,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_exportaciones2021 <- d_dieeven14 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/153.665955040775)*100,na.rm=T))
    t_exportaciones21 <- t_exportaciones2021 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb10_1_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb10_1_2,sheet = "1.2.2.",t_exportaciones21, startCol = 4,startRow = 19,colNames = F) ##escribir
    tabulado10_1_2 <- saveWorkbook(wb10_1_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)    
        
######################TABULADO 1.2.3##################################
#  VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) #
#              ANIO 2021 POR FORMA INSTITUCIONAL                  #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(forma_institucional,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

# Calculo de las variables.
t_participacion <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_participacion$total_ventas,na.rm =T )
t_participacion$porcentaje <- t_participacion$total_ventas / total

#Lectura catalogo de variables.
des_participacion <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_participacion,t_participacion,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb11<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb11,sheet = "1.2.3.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb11,sheet = "1.2.3.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb11,sheet = "1.2.3.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb11,sheet = "1.2.3.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb11,"1.2.3.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb11,"1.2.3.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado11 <- saveWorkbook(wb11,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#############################TABULADO 1.2.4#########################################
#   VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2021   #
#                        POR TAMANO DE EMPRESA                                  #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamanoe_plazas,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamanoventas <- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoventas$total_ventas,na.rm =T )
t_tamanoventas$porcentaje <- t_tamanoventas$total_ventas / total

#Lectura catalogo de variables.
des_tamanoventas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoventas,t_tamanoventas,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb12<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb12,sheet = "1.2.4.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb12,sheet = "1.2.4.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb12,sheet = "1.2.4.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb12,sheet = "1.2.4.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb12,"1.2.4.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb12,"1.2.4.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb12,"1.2.4.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado12 <- saveWorkbook(wb12,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#############################TABULADO 1.2.5#########################################
#   VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2021   #
#                        POR TAMANO DE EMPRESA (COP)                            #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(tamano_cop,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamanoventas <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoventas$total_ventas,na.rm =T )
t_tamanoventas$porcentaje <- t_tamanoventas$total_ventas / total

#Lectura catalogo de variables.
des_tamanoventas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoventas,t_tamanoventas,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb13<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb13,sheet = "1.2.5.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb13,sheet = "1.2.5.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb13,sheet = "1.2.5.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb13,sheet = "1.2.5.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb13,"1.2.5.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb13,"1.2.5.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb13,"1.2.5.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado13 <- saveWorkbook(wb13,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb13)

#####################TABULADO 1.2.6####################################
#  VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#            ANIO 2021 POR SECTOR ECONOMICO                        #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,ventas_totales,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_sectorventas <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_sectorventas$total_ventas,na.rm =T )
t_sectorventas$porcentaje <- t_sectorventas$total_ventas / total

#Lectura catalogo de variables.
des_sectorventas <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorventas,t_sectorventas,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb14<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb14,sheet = "1.2.6.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb14,sheet = "1.2.6.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb14,sheet = "1.2.6.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb14,sheet = "1.2.6.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb14,"1.2.6.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb14,"1.2.6.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado14 <- saveWorkbook(wb14,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###################TABULADO 1.2.7###################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE),#
#       ANIO 2021 POR ACTIVIDAD ECONOMICA                       #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_seccventas <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccventas$total_ventas,na.rm =T )
t_seccventas$porcentaje <- t_seccventas$total_ventas / total

#Lectura catalogo de variables.
des_seccventas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccventas,t_seccventas,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb15<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb15,sheet = "1.2.7.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb15,sheet = "1.2.7.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb15,sheet = "1.2.7.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb15,sheet = "1.2.7.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb15,"1.2.7.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb15,"1.2.7.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado15 <- saveWorkbook(wb15,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 1.2.8###############################
#VENTAS TOTALES SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE),#
#          ANIO 2021 POR PROVINCIA                           #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_provincia,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_provventas <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_provventas$total_ventas,na.rm =T )
t_provventas$porcentaje <- t_provventas$total_ventas / total

#Lectura catalogo de variables.
des_provventas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provventas,t_provventas,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb16<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb16,sheet = "1.2.8.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb16,sheet = "1.2.8.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb16,sheet = "1.2.8.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb16,sheet = "1.2.8.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb16,"1.2.8.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb16,"1.2.8.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado16 <- saveWorkbook(wb16,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#########1.3 SECCION III: plazas de empleo registrado, empleo registrado y masa salarial##################

###############TABULADO 1.3.1####################################
#PLAZAS DE EMPEO REGISTRADO EQUIVALENTE (UNIVERSO DIEE) PERIODO 2006-2021#

#######PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006 - 2011 POR ANIO
d_plazas <- bd_diee1 %>% select(plazas_equiv,plazas_equiv_hombres,plazas_equiv_mujeres,anio,situacion)

#total empresas del año 2006-2011#
t_plazas <- d_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T),
                                                  "total_plazashombres" =sum(plazas_equiv_hombres,na.rm=T),
                                                  "total_plazasmujeres"=sum(plazas_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb17<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb17,sheet = "1.3.1.",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
writeData(wb17,sheet = "1.3.1.",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
writeData(wb17,sheet = "1.3.1.",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb17,"1.3.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb17,"1.3.1.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado17 <- saveWorkbook(wb17,"Tabulados_DIEE_2021.xlsx",overwrite = T)

########PLAZAS DE EMPEO REGISTRADO EQUIVALENTE (UNIVERSO DIEE), PERIODO 2012 - 2021 POR ANIO

bd_plazas <- bd_diee %>% select(plazas_equiv,plazas_equiv_hombres,plazas_equiv_mujeres,anio,situacion)
bd_plazas1 <- bd_plazas %>% filter (situacion ==1)

#total empresas del año 2012-2021#
t_plazas <- bd_plazas1 %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T),
                                                     "total_plazashombres" =sum(plazas_equiv_hombres,na.rm=T),
                                                     "total_plazasmujeres"=sum(plazas_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb171<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb171,sheet = "1.3.1.",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
writeData(wb171,sheet = "1.3.1.",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
writeData(wb171,sheet = "1.3.1.",t_plazas, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb171,"1.3.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb171,"1.3.1.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado171 <- saveWorkbook(wb171,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#######################TABULADO 1.3.2##################################################
#############PLAZAS DE EMPLEO REGISTRADO EQUIVALENTE (UNIVERSO DIEE), POR RANGO DE EDAD A?O 2021

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_plazas <- bd_dieeact %>% select(plazas_rango_edad_1,plazas_rango_edad_2,
                                   plazas_rango_edad_3,plazas_rango_edad_4, 
                                   plazas_rango_edad_5, situacion)

#Calculo de las variables.
t_plazasre1 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_1,na.rm=T), porcentaje = 0)
t_plazasre2 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_2,na.rm=T), porcentaje = 0)
t_plazasre3 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_3,na.rm=T), porcentaje = 0)
t_plazasre4 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_4,na.rm=T), porcentaje = 0)
t_plazasre5 <- bd_plazas %>% summarise ("total_plazas"=sum(plazas_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangos1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_plazasre1))
t_rangos2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_plazasre2))
t_rangos3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_plazasre3))
t_rangos4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_plazasre4))
t_rangos5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_plazasre5))

tabla1 <- data.frame (rbind(t_rangos1,t_rangos2,t_rangos3, t_rangos4, t_rangos5))
total <- sum(tabla1$total_plazas,na.rm = T)
tabla1$porcentaje <- tabla1$total_plazas/total

#Exportar resultados a excel
wb18<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb18,sheet = "1.3.2.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb18,sheet = "1.3.2.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb18,sheet = "1.3.2.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb18,sheet = "1.3.2.",tabla1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb18,"1.3.2.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb18,"1.3.2.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb18,"1.3.2.",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado18 <- saveWorkbook(wb18,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#######################TABULADO 1.3.3#############################################
#PLAZAS DE EMPLEO REGISTRADO EQUIVALENTE (UNIVERSO DIEE), ANIO 2021 POR FORMA INSTITUCIONAL#

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_plazas <- bd_dieeact %>% select(plazas_equiv,forma_institucional,situacion)

#Calculo de las variables.
t_plazasins <- bd_plazas %>% group_by(forma_institucional) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_plazasins$total_plazas,na.rm =T )
t_plazasins$porcentaje <- t_plazasins$total_plazas / total

#Lectura catalogo de variables.
des_plazasinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_plazasinst,t_plazasins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb19<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb19,sheet = "1.3.3.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb19,sheet = "1.3.3.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb19,sheet = "1.3.3.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb19,sheet = "1.3.3.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb19,"1.3.3.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb19,"1.3.3.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado19 <- saveWorkbook(wb19,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##############################TABULADO 1.3.4##############################################
##PARTICIPACION DEL PERSONAL AFILIADO EQUIVALENTE (UNIVERSO DIEE), ANIO 2021 POR TAMANO DE EMPRESA#

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamanoe_plazas,plazas_equiv,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamanoplazas <- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=TRUE), porcentaje = 0)
total <- sum(t_tamanoplazas$total_plazas,na.rm =TRUE )
t_tamanoplazas$porcentaje <- t_tamanoplazas$total_plazas / total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanoplazas,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb20<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb20,sheet = "1.3.4.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb20,sheet = "1.3.4.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb20,sheet = "1.3.4.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb20,sheet = "1.3.4.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb20,"1.3.4.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb20,"1.3.4.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb20,"1.3.4.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado20 <- saveWorkbook(wb20,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##############################TABULADO 1.3.5####################################################
##PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2021 POR TAMANO DE EMPRESA (COP)#

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamano_cop,plazas_equiv,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamano_cop <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamano_cop$total_plazas,na.rm =T )
t_tamano_cop$porcentaje <- t_tamano_cop$total_plazas / total

#Lectura catalogo de variables.
des_tamano_cop <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamano_cop,t_tamano_cop,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb21<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb21,sheet = "1.3.5.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb21,sheet = "1.3.5.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb21,sheet = "1.3.5.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb21,sheet = "1.3.5.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb21,"1.3.5.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb21,"1.3.5.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb21,"1.3.5.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado21 <- saveWorkbook(wb21,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb21)

###########################TABULADO 1.3.6###############################################
#PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2021 POR SECTOR ECONOMICO#

#seleccion de variables###
df1 <- bd_diee %>% select(gsectores,plazas_equiv,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_sectorplazas <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_sectorplazas$total_plazas,na.rm =T )
t_sectorplazas$porcentaje <- t_sectorplazas$total_plazas / total

#Lectura catalogo de variables.
des_sectorplazas <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorplazas,t_sectorplazas,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb22<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb22,sheet = "1.3.6.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb22,sheet = "1.3.6.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb22,sheet = "1.3.6.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb22,sheet = "1.3.6.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb22,"1.3.6.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb22,"1.3.6.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado22 <- saveWorkbook(wb22,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###########################TABULADO 1.3.7##############################
#PERSONAL AFILIADO SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) #
#            ANIO 2021 POR ACTIVIDAD ECONOMICA                     #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,plazas_equiv,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#calculo#
t_seccplazas <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_seccplazas$total_plazas,na.rm =T )
t_seccplazas$porcentaje <- t_seccplazas$total_plazas / total

#Lectura catalogo de variables.
des_seccplazas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccplazas,t_seccplazas,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb23<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb23,sheet = "1.3.7.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb23,sheet = "1.3.7.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb23,sheet = "1.3.7.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb23,sheet = "1.3.7.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb23,"1.3.7.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb23,"1.3.7.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado23 <- saveWorkbook(wb23,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##############################TABULADO 1.3.8############################
#  PERSONAL AFILIADO SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE),  #  
#                     ANIO 2021 POR PROVINCIA                       #

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_provincia,plazas_equiv,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_provplazas <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_provplazas$total_plazas,na.rm =T )
t_provplazas$porcentaje <- t_provplazas$total_plazas / total

#Lectura catalogo de variables.
des_provplazas <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provplazas,t_provplazas,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb24<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb24,sheet = "1.3.8.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb24,sheet = "1.3.8.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb24,sheet = "1.3.8.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb24,sheet = "1.3.8.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb24,"1.3.8.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb24,"1.3.8.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado24 <- saveWorkbook(wb24,"Tabulados_DIEE_2021.xlsx",overwrite = T)

########TABULADO 1.3.9##############################################
#PERSONAL AFILIADO - EMPLEO (UNIVERSO DIEE), PERIODO 2006 - 2021 POR ANIO#

#BASE GENERAL 2006 - 2011
d_empleo <- bd_diee1 %>% select(empleo_equiv,empleo_equiv_hombres,empleo_equiv_mujeres,anio,situacion)

#total empresas del año 2006-2011
t_empleoafi <- d_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T),
                                                     "total_empleohombres" =sum(empleo_equiv_hombres,na.rm=T),
                                                     "total_empleomujeres"=sum(empleo_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb25<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb25,sheet = "1.3.9.",t_empleoafi, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb25,"1.3.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb25,"1.3.9.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado25 <- saveWorkbook(wb25,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#BASE GENERAL 2012-2021
bd_empleo2 <- bd_diee %>% select(empleo_equiv,empleo_equiv_hombres,empleo_equiv_mujeres,ventas_totales,anio,situacion)
bd_empleo2 <- bd_empleo2 %>% filter (situacion ==1)

#total empresas del anio 2012-2021#
t_empleoafi <- bd_empleo2 %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T),
                                                    "total_empleohombres" =sum(empleo_equiv_hombres,na.rm=T),
                                                    "total_empleomujeres"=sum(empleo_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb252<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb252,sheet = "1.3.9.",t_empleoafi, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb252,"1.3.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb252,"1.3.9.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado252 <- saveWorkbook(wb252,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 1.3.10#######################################
#EMPLEO REGISTRADO (UNIVERSO DIEE), A?O 2021 POR RANGO DE EDAD#
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_empleo <- bd_dieeact %>% select(empleo_rango_edad_1,empleo_rango_edad_2,
                                   empleo_rango_edad_3,empleo_rango_edad_4, 
                                   empleo_rango_edad_5, situacion)

#Calculo de las variables.
t_empleore1 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_1,na.rm=T), porcentaje = 0)
t_empleore2 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_2,na.rm=T), porcentaje = 0)
t_empleore3 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_3,na.rm=T), porcentaje = 0)
t_empleore4 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_4,na.rm=T), porcentaje = 0)
t_empleore5 <- bd_empleo %>% summarise ("total_empleo"=sum(empleo_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangos1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_empleore1))
t_rangos2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_empleore2))
t_rangos3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_empleore3))
t_rangos4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_empleore4))
t_rangos5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_empleore5))

tabla1 <- data.frame (rbind(t_rangos1,t_rangos2,t_rangos3, t_rangos4, t_rangos5))
total <- sum(tabla1$total_empleo,na.rm = T)
tabla1$porcentaje <- tabla1$total_empleo/total

#Exportar resultados a excel
wb26<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb26,sheet = "1.3.10.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb26,sheet = "1.3.10.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb26,sheet = "1.3.10.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb26,sheet = "1.3.10.",tabla1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb26,"1.3.10.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb26,"1.3.10.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb26,"1.3.10.",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado26 <- saveWorkbook(wb26,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 1.3.11#######################################
#EMPLEO REGISTRADO (UNIVERSO DIEE), ANIO 2021 POR FORMA INSTITUCIONAL# 

#Filtrar empresas activas del año del cual se requiere
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_empleo <- bd_dieeact %>% select(empleo_equiv,forma_institucional,situacion)

#Calculo de las variables.
t_empformains <- bd_empleo %>% group_by(forma_institucional) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_empformains$total_empleo,na.rm =T )
t_empformains$porcentaje <- t_empformains$total_empleo / total

#Lectura catalogo de variables.
des_empformainst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_empformainst,t_empformains,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb27<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb27,sheet = "1.3.11.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb27,sheet = "1.3.11.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb27,sheet = "1.3.11.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb27,sheet = "1.3.11.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb27,"1.3.11.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb27,"1.3.11.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado27 <- saveWorkbook(wb27,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###########################TABULADO 1.3.12#################################################
# PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2021 POR TAMANO DE EMPRESA#

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanoe_empleo,empleo_equiv,anio,situacion)
#Seleccion de variables que se requieren para el tabulado.
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamanoempleo <- bd_dieeact %>% group_by(tamanoe_empleo) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoempleo$total_empleo,na.rm =T )
t_tamanoempleo$porcentaje <- t_tamanoempleo$total_empleo / total

#Lectura catalogo de variables.
des_tamanoempleo <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoempleo,t_tamanoempleo,by.x = "CODIGO",by.y = "tamanoe_empleo",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb28<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb28,sheet = "1.3.12.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb28,sheet = "1.3.12.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb28,sheet = "1.3.12.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb28,sheet = "1.3.12.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb28,"1.3.12.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb28,"1.3.12.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb28,"1.3.12.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
estilo  <-  createStyle (fontColour  =  rgb (1 ,  1 ,  1) )
addStyle(wb28,"1.3.12.",estilo,cols= 2:3, rows = 13,gridExpand = TRUE,stack=TRUE)
tabulado28 <- saveWorkbook(wb28,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###########################TABULADO 1.3.13########################################################
# PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2021 POR TAMANO DE EMPRESA (COP) #

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamano_cop,empleo_equiv,anio,situacion)
#Seleccion de variables que se requieren para el tabulado.
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_tamanocopemp <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamanocopemp$total_empleo,na.rm =T )
t_tamanocopemp$porcentaje <- t_tamanocopemp$total_empleo / total

#Lectura catalogo de variables.
des_tamanocopemp <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanocopemp,t_tamanocopemp,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb29<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb29,sheet = "1.3.13.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb29,sheet = "1.3.13.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb29,sheet = "1.3.13.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb29,sheet = "1.3.13.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb29,"1.3.13.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb29,"1.3.13.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb29,"1.3.13.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado29 <- saveWorkbook(wb29,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb29)

###################################TABULADO 1.3.14#######################################
#PARTICIPACION DEL PERSONAL AFILIADO (UNIVERSO DIEE), ANIO 2021 POR SECTOR ECONOMICO#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,empleo_equiv,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#calculo#
t_sectorempleo <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_sectorempleo$total_empleo,na.rm =T )
t_sectorempleo$porcentaje <- t_sectorempleo$total_empleo / total

#Lectura catalogo de variables.
des_sectorempleo <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorempleo,t_sectorempleo,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb30<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb30,sheet = "1.3.14.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb30,sheet = "1.3.14.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb30,sheet = "1.3.14.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb30,sheet = "1.3.14.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb30,"1.3.14.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb30,"1.3.14.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado30 <- saveWorkbook(wb30,"Tabulados_DIEE_2021.xlsx",overwrite = T)

######################TABULADO 1.3.15##################################
#PERSONAL AFILIADO SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)# 
#         ANIO 2021 POR ACTIVIDAD ECONOMICA                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,empleo_equiv,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_seccempleo <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_seccempleo$total_empleo,na.rm =T )
t_seccempleo$porcentaje <- t_seccempleo$total_empleo / total

#Lectura catalogo de variables.
des_seccempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccempleo,t_seccempleo,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb31<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb31,sheet = "1.3.15.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb31,sheet = "1.3.15.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb31,sheet = "1.3.15.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb31,sheet = "1.3.15.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb31,"1.3.15.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb31,"1.3.15.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado31 <- saveWorkbook(wb31,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#########TABULADO 1.3.16##########################
#EMPLEO REGISTRADO (UNIVERSO DIEE), ANIO 2021#
#           POR PROVINCIA                    #  

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,empleo_equiv,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_provempleo <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_provempleo$total_empleo,na.rm =T )
t_provempleo$porcentaje <- t_provempleo$total_empleo / total

#Lectura catalogo de variables.
des_provempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provempleo,t_provempleo,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb32<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb32,sheet = "1.3.16.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb32,sheet = "1.3.16.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb32,sheet = "1.3.16.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb32,sheet = "1.3.16.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb32,"1.3.16.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb32,"1.3.16.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado32 <- saveWorkbook(wb32,"Tabulados_DIEE_2021.xlsx",overwrite = T)

################################TABULADO 1.3.17##########################################
#       MASA SALARIAL (UNIVERSO DIEE), PERIODO 2006 - 2021 POR ANIO                 #

#BASE GENERAL 2006-2011
d_remuneracion <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)

#total empresas del año 2006-2011
t_remuneraciones <- d_remuneracion %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb33<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb33,sheet = "1.3.17.",t_remuneraciones, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb33,"1.3.17.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb33,"1.3.17.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado33 <- saveWorkbook(wb33,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#BASE GENERAL 2012-2021
d_remuneracion <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_remuneracion1 <- d_remuneracion %>% filter(situacion ==1)

#total empresas del año 2012-2021#
t_remuneraciones <- d_remuneracion1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                    "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                    "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb331<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb331,sheet = "1.3.17.",t_remuneraciones, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb331,"1.3.17.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb331,"1.3.17.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado331 <- saveWorkbook(wb331,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#################TABULADO 1.3.18 : CONSTANTES#################################
#MASA SALARIAL (UNIVERSO DIEE), PERIODO 2006 - 2021 POR ANIO#

#lectura de base 2006
bd_dieems <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems1 <- bd_dieems %>% filter (anio == 2006 & situacion == 1)
t_masa2006 <- d_dieems1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/96.78695716)*100,na.rm=T),
                                                  "total_remuneracioneshombres" =sum((remuneraciones_hombres/96.7869571635269)*100,na.rm=T),
                                                  "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/96.78695716)*100,na.rm=T))
#Exportar resultados a excel
wb34<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb34,sheet = "1.3.18.",t_masa2006, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado34 <- saveWorkbook(wb34,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2007
bd_dieems1 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems2 <- bd_dieems1 %>% filter (anio == 2007 & situacion == 1)
t_masa2007 <- d_dieems2 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/100.0000000)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/100.0000000)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/100.0000000)*100,na.rm=T))
#Exportar resultados a excel
wb341<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb341,sheet = "1.3.18.",t_masa2007, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado341 <- saveWorkbook(wb341,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2008
bd_dieems2 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems3 <- bd_dieems2 %>% filter (anio == 2008 & situacion == 1)
t_masa2008 <- d_dieems3 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/108.83054136472500)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/108.83054136472500)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/108.83054136472500)*100,na.rm=T))
#Exportar resultados a excel
wb342<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb342,sheet = "1.3.18.",t_masa2008, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado342 <- saveWorkbook(wb342,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2009
bd_dieems3 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems4 <- bd_dieems3 %>% filter (anio == 2009 & situacion == 1)
t_masa2009 <- d_dieems4 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/113.5230353096400)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/113.5230353096400)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/113.5230353096400)*100,na.rm=T))
#Exportar resultados a excel
wb343<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb343,sheet = "1.3.18.",t_masa2009, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado343 <- saveWorkbook(wb343,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2010
bd_dieems4 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems5 <- bd_dieems4 %>% filter (anio == 2010 & situacion == 1)
t_masa2010 <- d_dieems5 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/117.3011217423320)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/117.3011217423320)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/117.3011217423320)*100,na.rm=T))
#Exportar resultados a excel
wb344<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb344,sheet = "1.3.18.",t_masa2010, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado344 <- saveWorkbook(wb344,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2011
bd_dieems5 <- bd_diee1 %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems6 <- bd_dieems5 %>% filter (anio == 2011 & situacion == 1)
t_masa2011 <- d_dieems6 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/123.6463878309520)*100,na.rm=T))
#Exportar resultados a excel
wb345<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb345,sheet = "1.3.18.",t_masa2011, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado345 <- saveWorkbook(wb345,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2012
bd_dieems6 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems7 <- bd_dieems6 %>% filter (anio == 2012 & situacion == 1)
t_masa2012 <- d_dieems7 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/128.7949116563170)*100,na.rm=T))
#Exportar resultados a excel
wb346<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb346,sheet = "1.3.18.",t_masa2012, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado346 <- saveWorkbook(wb346,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2013
bd_dieems7 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems8 <- bd_dieems7 %>% filter (anio == 2013 & situacion == 1)
t_masa2013 <- d_dieems8 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/132.2728147645030)*100,na.rm=T))
#Exportar resultados a excel
wb347<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb347,sheet = "1.3.18.",t_masa2013, startCol = 1,startRow = 14,colNames = F) ##escribir
tabulado347 <- saveWorkbook(wb347,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2014
bd_dieems8 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems9 <- bd_dieems8 %>% filter (anio == 2014 & situacion == 1)
t_masa2014 <- d_dieems9 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/137.1237313761930)*100,na.rm=T))
#Exportar resultados a excel
wb348<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb348,sheet = "1.3.18.",t_masa2014, startCol = 1,startRow = 15,colNames = F) ##escribir
tabulado348 <- saveWorkbook(wb348,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2015
bd_dieems9 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems10 <- bd_dieems9 %>% filter (anio == 2015 & situacion == 1)
t_masa2015 <- d_dieems10 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/141.7586850842260)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/141.7586850842260)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/141.7586850842260)*100,na.rm=T))
#Exportar resultados a excel
wb349<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb349,sheet = "1.3.18.",t_masa2015, startCol = 1,startRow = 16,colNames = F) ##escribir
tabulado349 <- saveWorkbook(wb349,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2016
bd_dieems10 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems11 <- bd_dieems10 %>% filter (anio == 2016 & situacion == 1)
t_masa2016 <- d_dieems11 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.3460867154060)*100,na.rm=T))
#Exportar resultados a excel
wb3410<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3410,sheet = "1.3.18.",t_masa2016, startCol = 1,startRow = 17,colNames = F) ##escribir
tabulado3410 <- saveWorkbook(wb3410,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2017
bd_dieems11 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems12 <- bd_dieems11 %>% filter (anio == 2017 & situacion == 1)
t_masa2017 <- d_dieems12 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.0641241843250)*100,na.rm=T))
#Exportar resultados a excel
wb3411<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3411,sheet = "1.3.18.",t_masa2017, startCol = 1,startRow = 18,colNames = F) ##escribir
addStyle(wb3411,"1.3.18.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3411,"1.3.18.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3411 <- saveWorkbook(wb3411,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2018
bd_dieems12 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems121 <- bd_dieems12 %>% filter (anio == 2018 & situacion == 1)
t_masa2018 <- d_dieems121 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.444918475971)*100,na.rm=T),
                                                            "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.444918475971)*100,na.rm=T),
                                                            "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.444918475971)*100,na.rm=T))
#Exportar resultados a excel
wb3412<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3412,sheet = "1.3.18.",t_masa2018, startCol = 1,startRow = 19,colNames = F) ##escribir
addStyle(wb3412,"1.3.18.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3412,"1.3.18.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3412 <- saveWorkbook(wb3412,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2019
bd_dieems13 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems122 <- bd_dieems13 %>% filter (anio == 2019 & situacion == 1)
t_masa2019 <- d_dieems122 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.344842799337)*100,na.rm=T))
#Exportar resultados a excel
wb3413<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3413,sheet = "1.3.18.",t_masa2019, startCol = 1,startRow = 20,colNames = F) ##escribir
addStyle(wb3413,"1.3.18.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3413,"1.3.18.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3413 <- saveWorkbook(wb3413,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2020
bd_dieems14 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems132 <- bd_dieems14 %>% filter (anio == 2020 & situacion == 1)
t_masa2020 <- d_dieems132 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/142.009628029416)*100,na.rm=T),
                                                            "total_remuneracioneshombres" =sum((remuneraciones_hombres/142.009628029416)*100,na.rm=T),
                                                            "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/142.009628029416)*100,na.rm=T))
#Exportar resultados a excel
wb3414<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3414,sheet = "1.3.18.",t_masa2020, startCol = 1,startRow = 21,colNames = F) ##escribir
addStyle(wb3414,"1.3.18.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3414,"1.3.18.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3414 <- saveWorkbook(wb3414,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2021
bd_dieems15 <- bd_diee %>% select(remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieems142 <- bd_dieems15 %>% filter (anio == 2021 & situacion == 1)
t_masa2021 <- d_dieems142 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/144.775430052823)*100,na.rm=T),
                                                            "total_remuneracioneshombres" =sum((remuneraciones_hombres/144.775430052823)*100,na.rm=T),
                                                            "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/144.775430052823)*100,na.rm=T))
#Exportar resultados a excel
wb3415<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb3415,sheet = "1.3.18.",t_masa2021, startCol = 1,startRow = 22,colNames = F) ##escribir
addStyle(wb3415,"1.3.18.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb3415,"1.3.18.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado3415 <- saveWorkbook(wb3415,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#######################TABULADO 1.3.19################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#              ANIO 2021 POR FORMA INSTITUCIONAL                 #

#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )
#Seleccion de variables que se requieren para el tabulado.
bd_remuneraciones <- bd_dieeact %>% select(remuneraciones,forma_institucional,situacion)

#calculo#
t_remuneracionesins <- bd_remuneraciones %>% group_by(forma_institucional) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_remuneracionesins$total_remuneraciones,na.rm =T )
t_remuneracionesins$porcentaje <- t_remuneracionesins$total_remuneraciones / total

#Lectura catalogo de variables.
des_remuneracionesinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_remuneracionesinst,t_remuneracionesins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remuneraciones,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb35<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb35,sheet = "1.3.19.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb35,sheet = "1.3.19.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb35,sheet = "1.3.19.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb35,sheet = "1.3.19.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb35,"1.3.19.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb35,"1.3.19.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado35 <- saveWorkbook(wb35,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##########################TABULADO 1.3.20##################################
###   MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) ### 
###              ANIO 2021 POR TAMANO DE EMPRESA                    ###

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanoe_plazas,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 )

#calculo#
t_tamanoremu <- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb36<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb36,sheet = "1.3.20.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb36,sheet = "1.3.20.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb36,sheet = "1.3.20.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb36,sheet = "1.3.20.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb36,"1.3.20.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb36,"1.3.20.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb36,"1.3.20.",grisStyle,cols= 5:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado36 <- saveWorkbook(wb36,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##########################TABULADO 1.3.21##################################
###   MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE) ### 
###              ANIO 2021 POR TAMANO DE EMPRESA    (COP)           ###

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamano_cop,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 )

#calculo#
t_tamanoremu <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb37<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb37,sheet = "1.3.21.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb37,sheet = "1.3.21.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb37,sheet = "1.3.21.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb37,sheet = "1.3.21.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb37,"1.3.21.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb37,"1.3.21.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb37,"1.3.21.",grisStyle,cols= 5:7, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado37 <- saveWorkbook(wb37,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb37)

#############################TABULADO 1.3.22#########################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE)  #
#           ANIO 2021 POR SECTOR ECONOMICO                      #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#calculo#
t_sectorremu<- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_sectorremu$total_remu,na.rm =T )
t_sectorremu$porcentaje <- t_sectorremu$total_remu / total
                            
#Lectura catalogo de variables.
des_sectorremu <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorremu,t_sectorremu,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb38<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb38,sheet = "1.3.22.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb38,sheet = "1.3.22.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb38,sheet = "1.3.22.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb38,sheet = "1.3.22.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb38,"1.3.22.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb38,"1.3.22.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado38 <- saveWorkbook(wb38,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###########################TABULADO 1.3.23############################
##MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE),## 
#              ANIO 2021 POR ACTIVIDAD ECONOMICA                 #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_seccremu <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_seccremu$total_remu,na.rm =T )
t_seccremu$porcentaje <- t_seccremu$total_remu / total

#Lectura catalogo de variables.
des_seccremu <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccremu,t_seccremu,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb39<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb39,sheet = "1.3.23.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb39,sheet = "1.3.23.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb39,sheet = "1.3.23.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb39,sheet = "1.3.23.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb39,"1.3.23.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb39,"1.3.23.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado39 <- saveWorkbook(wb39,"Tabulados_DIEE_2021.xlsx",overwrite = T)

######################TABULADO 1.3.24####################################################
#MASA SALARIAL SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021 POR PROVINCIA#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,remuneraciones,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 )

#Calculo de las variables.
t_provremu <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_provremu$total_remu,na.rm =T )
t_provremu$porcentaje <- t_provremu$total_remu / total

#Lectura catalogo de variables.
des_provremu <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provremu,t_provremu,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb40<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb40,sheet = "1.3.24.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb40,sheet = "1.3.24.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb40,sheet = "1.3.24.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb40,sheet = "1.3.24.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb40,"1.3.24.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb40,"1.3.24.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado40 <- saveWorkbook(wb40,"Tabulados_DIEE_2021.xlsx",overwrite = T)

######EMPRESAS QUE REGISTRAN VENTAS Y EMPLEO DE ACTIVIDADES PRODUCTIVAS (SE EXCLUYE SECCIONES O,P,Q)**#####
#########2.1 SECCION I: número de empresas, ventas, plazas de empleo, empleo registrado y masa salarial##################

###########################TABULADO 2.1.1###############################################
#TOTAL EMPRESAS (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2021 POR ANIO#

#BASE GENERAL 2011 
#Seleccion de variables que se requieren para el tabulado.
d_act <- bd_diee1 %>% select(estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
d_act1 <- d_act %>% filter(situacion == 1 & estructura_estrat == 1 & anio== 2011)

#total empresas del año 2006-2011#
t_actprod <- d_act1 %>% group_by(anio) %>% summarise ("total_actprod"= n())

#Exportar resultados a excel
wb41<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb41,sheet = "2.1.1.",t_actprod, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb41,"2.1.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb41,"2.1.1.",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado41 <- saveWorkbook(wb41,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#BASE GENERAL 2012-2021
d_act <- bd_diee %>% select(estructura_estrat,codigo_seccion,anio,situacion)
d_act2<- d_act %>% filter(situacion ==1 & estructura_estrat ==1 )

#total empresas del año 2012-2021
t_actprod2 <- d_act2 %>% group_by(anio) %>% summarise ("total_actprod"= n())

#Exportar resultados a excel
wb411<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb411,sheet = "2.1.1.",t_actprod2, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb411,"2.1.1.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb411,"2.1.1.",grisStyle,cols= 1:2, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado411 <- saveWorkbook(wb411,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##################################TABULADO 2.1.2####################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2021 POR FORMA INSTITUCIONAL                                #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,forma_institucional,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_actfi <- bd_dieeact %>% group_by (forma_institucional) %>% summarise ("total_actfi"= n(), porcentaje = 0)
total <- sum(t_actfi$total_actfi,na.rm =T )
t_actfi$porcentaje <- t_actfi$total_actfi / total

#Lectura catalogo de variables.
des_actfi <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_actfi,t_actfi,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_actfi,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb42<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb42,sheet = "2.1.2.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb42,sheet = "2.1.2.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb42,sheet = "2.1.2.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb42,sheet = "2.1.2.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb42,"2.1.2.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb42,"2.1.2.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado42 <- saveWorkbook(wb42,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###############################TABULADO 2.1.3#######################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2021 POR TAMANO DE EMPRESAS                          #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,tamanoe_plazas,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_tamanoat<- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise ("total_at"= n(), porcentaje = 0)
total <- sum(t_tamanoat$total_at,na.rm =T )
t_tamanoat$porcentaje <- t_tamanoat$total_at / total

#Lectura catalogo de variables.
des_tamanoat <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoat,t_tamanoat,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_at,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb43<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb43,sheet = "2.1.3.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb43,sheet = "2.1.3.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb43,sheet = "2.1.3.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb43,sheet = "2.1.3.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb43,"2.1.3.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb43,"2.1.3.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb43,"2.1.3.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado43 <- saveWorkbook(wb43,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###############################TABULADO 2.1.4#######################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2021 POR TAMANO DE EMPRESAS       (COP)              #

#Seleccion de variables que se requieren para el tabulado.
bd_actprod <- bd_diee %>% select(anio,codigo_seccion,estructura_estrat,tamano_cop,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- bd_actprod%>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1 )

#Calculo de las variables.
t_tamanoat<- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_at"= n(), porcentaje = 0)
total <- sum(t_tamanoat$total_at,na.rm =T )
t_tamanoat$porcentaje <- t_tamanoat$total_at / total

#Lectura catalogo de variables.
des_tamanoat <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoat,t_tamanoat,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_at,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb44<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb44,sheet = "2.1.4.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb44,sheet = "2.1.4.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb44,sheet = "2.1.4.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb44,sheet = "2.1.4.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb44,"2.1.4.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb44,"2.1.4.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb44,"2.1.4.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado44 <- saveWorkbook(wb44,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb44)

#################TABULADO 2.1.5######################################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #
#           ANIO 2021 POR SECTOR ECONOMICO                                       #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(gsectores,codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_sectorap<- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_sectorap$total_ap,na.rm =T )
t_sectorap$porcentaje <- t_sectorap$total_ap / total

#Lectura catalogo de variables.
des_sectorap <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorap,t_sectorap,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb45<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb45,sheet = "2.1.5.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb45,sheet = "2.1.5.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb45,sheet = "2.1.5.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb45,sheet = "2.1.5.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb45,"2.1.5.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb45,"2.1.5.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado45 <- saveWorkbook(wb45,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#########################TABULADO 2.1.6#############################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                     ANIO 2021, POR ACTIVIDAD ECONOMICA                        #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_seccap<- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_seccap$total_ap,na.rm =T )
t_seccap$porcentaje <- t_seccap$total_ap / total

#Lectura catalogo de variables.
des_seccap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_seccap,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb46<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb46,sheet = "2.1.6.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb46,sheet = "2.1.6.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb46,sheet = "2.1.6.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb46,sheet = "2.1.6.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb46,"2.1.6.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb46,"2.1.6.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado46 <- saveWorkbook(wb46,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#######################TABULADO 2.1.7###############################################
#EMPRESAS SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2021 POR PROVINCIA                                          #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ap"= n(), porcentaje = 0)
total <- sum(t_provap$total_ap,na.rm =T )
t_provap$porcentaje <- t_provap$total_ap / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ap,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb47 <-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb47,sheet = "2.1.7.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb47,sheet = "2.1.7.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb47,sheet = "2.1.7.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb47,sheet = "2.1.7.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb47,"2.1.7.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb47,"2.1.7.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado47 <- saveWorkbook(wb47,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##########################TABULADO 2.1.8####################
#VENTAS TOTALES (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)  #       
#             PERIODO 2011 - 2021 POR ANIO              #

#Seleccion de variables que se requieren para el tabulado.
##BASE GENERAL 2011###
d_act <- bd_diee1 %>% select(estructura_estrat,codigo_seccion,ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_excact <- d_act %>% filter (estructura_estrat == 1, situacion ==1 , anio ==2011)

#total empresas del año 2006-2011#
t_actprod1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb48<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb48,sheet = "2.1.8.",t_actprod1, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb48,"2.1.8.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb48,"2.1.8.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado48 <- saveWorkbook(wb48,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    #total empresas del a?o 2009 - 2011#
    t_nacional1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
    t_nacional2 <- t_nacional1 %>% select(total_ventanacional)
    
    #Exportar resultados a excel
    wb48_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb48_1,sheet = "2.1.8.",t_nacional2, startCol = 3,startRow = 7,colNames = F) ##escribir
    tabulado48_1 <- saveWorkbook(wb48_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    #total empresas del a?o 2009 - 2011#
    t_expprod1 <- d_excact %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
    t_expprod2 <- t_expprod1 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb48_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb48_2,sheet = "2.1.8.",t_expprod2, startCol = 4,startRow = 7,colNames = F) ##escribir
    tabulado48_2 <- saveWorkbook(wb48_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##BASE GENERAL 2012-2021###
d_act1 <- bd_diee %>% select(estructura_estrat,codigo_seccion,ventas_totales,anio,situacion,ventas_nacionales,exportaciones_netas)
d_excact <- d_act1 %>% filter (estructura_estrat == 1, situacion ==1 )

#total empresas del año 2012-2021#
t_actprod <- d_excact %>% group_by(anio) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T))

#Exportar resultados a excel
wb481<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb481,sheet = "2.1.8.",t_actprod, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb481,"2.1.8.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb481,"2.1.8.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado481 <- saveWorkbook(wb481,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    #total empresas del a?o 2012 - 2021#
    t_vntanacional1_1 <- d_excact %>% group_by(anio) %>% summarise ("total_ventanacional"=sum(ventas_nacionales,na.rm=T))
    t_vntanacional2_2 <- t_vntanacional1_1 %>% select(total_ventanacional)
    
    #Exportar resultados a excel
    wb482<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb482,sheet = "2.1.8.",t_vntanacional2_2, startCol = 3,startRow = 8,colNames = F) ##escribir
    tabulado482 <- saveWorkbook(wb482,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    #total empresas del a?o 2012 - 2021#
    t_exp1_1 <- d_excact %>% group_by(anio) %>% summarise ("total_exportaciones"=sum(exportaciones_netas,na.rm=T))
    t_exp2_2 <- t_exp1_1 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_83<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_83,sheet = "2.1.8.",t_exp2_2, startCol = 4,startRow = 8,colNames = F) ##escribir
    tabulado4_83 <- saveWorkbook(wb4_83,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#####################TABULADO 2.1.9 (CONSTANTES)################################
#VENTAS TOTALES (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2021##

#lectura de base 2011
bd_dieeap <- bd_diee1 %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap <- bd_dieeap %>% filter (anio == 2011 & situacion == 1&estructura_estrat==1)
t_ventas2011 <- d_dieeap %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/130.12159330682)*100,na.rm=T))

#Exportar resultados a excel
wb49<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb49,sheet = "2.1.9.",t_ventas2011, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado49 <- saveWorkbook(wb49,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2011 <- d_dieeap %>% summarise ("total_ventas"=sum((ventas_nacionales/130.12159330682)*100,na.rm=T))
    t_vntnacional11<- t_vntnacional2011 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_1,sheet = "2.1.9.",t_vntnacional11, startCol = 3,startRow = 8,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2011 <- d_dieeap %>% summarise ("total_exportaciones"=sum((exportaciones_netas/130.12159330682)*100,na.rm=T))
    t_export11 <- t_export2011 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_2,sheet = "2.1.9.",t_export11, startCol = 4,startRow = 8,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2012
bd_dieeap1 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap1 <- bd_dieeap1 %>% filter (anio == 2012 & situacion == 1 & estructura_estrat==1)
t_ventas2012 <- d_dieeap1 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/136.608484020484)*100,na.rm=T))

#Exportar resultados a excel
wb491<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb491,sheet = "2.1.9.",t_ventas2012, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado491 <- saveWorkbook(wb491,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2012 <- d_dieeap1 %>% summarise ("total_ventas"=sum((ventas_nacionales/136.608484020484)*100,na.rm=T))
    t_vntnacional12<- t_vntnacional2012 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_1,sheet = "2.1.9.",t_vntnacional12, startCol = 3,startRow = 9,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2012 <- d_dieeap1 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/136.608484020484)*100,na.rm=T))
    t_export12 <- t_export2012 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_2,sheet = "2.1.9.",t_export12, startCol = 4,startRow = 9,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2013
bd_dieeap2 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap2 <- bd_dieeap2 %>% filter (anio == 2013 & situacion == 1 & estructura_estrat==1)
t_ventas2013 <- d_dieeap2 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/140.836583556647)*100,na.rm=T))

#Exportar resultados a excel
wb492<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb492,sheet = "2.1.9.",t_ventas2013, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado492 <- saveWorkbook(wb492,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2013 <- d_dieeap2 %>% summarise ("total_ventas"=sum((ventas_nacionales/140.836583556647)*100,na.rm=T))
    t_vntnacional13<- t_vntnacional2013 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_1,sheet = "2.1.9.",t_vntnacional13, startCol = 3,startRow = 10,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2013 <- d_dieeap2 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/140.836583556647)*100,na.rm=T))
    t_export13 <- t_export2013 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_2,sheet = "2.1.9.",t_export13, startCol = 4,startRow = 10,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2014
bd_dieeap3 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap3 <- bd_dieeap3 %>% filter (anio == 2014 & situacion == 1 & estructura_estrat==1)
t_ventas2014 <- d_dieeap3 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/145.104922216934)*100,na.rm=T))

#Exportar resultados a excel
wb493<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb493,sheet = "2.1.9.",t_ventas2014, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado493 <- saveWorkbook(wb493,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2014 <- d_dieeap3 %>% summarise ("total_ventas"=sum((ventas_nacionales/145.104922216934)*100,na.rm=T))
    t_vntnacional14<- t_vntnacional2014 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_1,sheet = "2.1.9.",t_vntnacional14, startCol = 3,startRow = 11,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2014 <- d_dieeap3 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/145.104922216934)*100,na.rm=T))
    t_export14 <- t_export2014 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_2,sheet = "2.1.9.",t_export14, startCol = 4,startRow = 11,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2015
bd_dieeap4 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap4 <- bd_dieeap4 %>% filter (anio == 2015 & situacion == 1 & estructura_estrat==1)
t_ventas2015 <- d_dieeap4 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/141.490328484162)*100,na.rm=T))

#Exportar resultados a excel
wb494<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb494,sheet = "2.1.9.",t_ventas2015, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado494 <- saveWorkbook(wb494,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2015 <- d_dieeap4 %>% summarise ("total_ventas"=sum((ventas_nacionales/141.490328484162)*100,na.rm=T))
    t_vntnacional15<- t_vntnacional2015 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_1,sheet = "2.1.9.",t_vntnacional15, startCol = 3,startRow = 12,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2015 <- d_dieeap4 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/141.490328484162)*100,na.rm=T))
    t_export15 <- t_export2015 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_2,sheet = "2.1.9.",t_export15, startCol = 4,startRow = 12,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2016
bd_dieeap5 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap5 <- bd_dieeap5 %>% filter (anio == 2016 & situacion == 1 & estructura_estrat==1)
t_ventas2016 <- d_dieeap5 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/144.180974753378)*100,na.rm=T))

#Exportar resultados a excel
wb495<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb495,sheet = "2.1.9.",t_ventas2016, startCol = 1,startRow = 13,colNames = F) ##escribir
tabulado495 <- saveWorkbook(wb495,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2016 <- d_dieeap5 %>% summarise ("total_ventas"=sum((ventas_nacionales/144.180974753378)*100,na.rm=T))
    t_vntnacional16<- t_vntnacional2016 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_9_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_1,sheet = "2.1.9.",t_vntnacional16, startCol = 3,startRow = 13,colNames = F) ##escribir
    tabulado4_9_1 <- saveWorkbook(wb4_9_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2016 <- d_dieeap5 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/144.180974753378)*100,na.rm=T))
    t_export16 <- t_export2016 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_9_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_9_2,sheet = "2.1.9.",t_export16, startCol = 4,startRow = 13,colNames = F) ##escribir
    tabulado4_9_2 <- saveWorkbook(wb4_9_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2017
bd_dieeap6 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap6 <- bd_dieeap6 %>% filter (anio == 2017 & situacion == 1 & estructura_estrat==1)
t_ventas2017 <- d_dieeap6 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/146.987310714795)*100,na.rm=T))

#Exportar resultados a excel
wb496<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb496,sheet = "2.1.9.",t_ventas2017, startCol = 1,startRow = 14,colNames = F) ##escribir
addStyle(wb496,"2.1.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb496,"2.1.9.",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado496 <- saveWorkbook(wb496,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2017 <- d_dieeap6 %>% summarise ("total_ventas"=sum((ventas_nacionales/146.987310714795)*100,na.rm=T))
    t_vntnacional17<- t_vntnacional2017 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_10_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_10_1,sheet = "2.1.9.",t_vntnacional17, startCol = 3,startRow = 14,colNames = F) ##escribir
    tabulado4_10_1 <- saveWorkbook(wb4_10_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2017 <- d_dieeap6 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/146.987310714795)*100,na.rm=T))
    t_export17 <- t_export2017 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_10_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_10_2,sheet = "2.1.9.",t_export17, startCol = 4,startRow = 14,colNames = F) ##escribir
    tabulado4_10_2 <- saveWorkbook(wb4_10_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2018
bd_dieeap7 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap7 <- bd_dieeap7 %>% filter (anio == 2018 & situacion == 1 & estructura_estrat==1)
t_ventas2018 <- d_dieeap7 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.660824062251)*100,na.rm=T))

#Exportar resultados a excel
wb497<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb497,sheet = "2.1.9.",t_ventas2018, startCol = 1,startRow = 15,colNames = F) ##escribir
addStyle(wb497,"2.1.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb497,"2.1.9.",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado497 <- saveWorkbook(wb497,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2018 <- d_dieeap7 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.660824062251)*100,na.rm=T))
    t_vntnacional18<- t_vntnacional2018 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_11_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_11_1,sheet = "2.1.9.",t_vntnacional18, startCol = 3,startRow = 15,colNames = F) ##escribir
    tabulado4_11_1 <- saveWorkbook(wb4_11_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2018 <- d_dieeap7 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.660824062251)*100,na.rm=T))
    t_export18 <- t_export2018 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_12_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_12_2,sheet = "2.1.9.",t_export18, startCol = 4,startRow = 15,colNames = F) ##escribir
    tabulado4_12_2 <- saveWorkbook(wb4_12_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2019
bd_dieeap8 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
d_dieeap8 <- bd_dieeap8 %>% filter (anio == 2019 & situacion == 1 & estructura_estrat==1)
t_ventas2019 <- d_dieeap8 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/150.402318656309)*100,na.rm=T))

#Exportar resultados a excel
wb498<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb498,sheet = "2.1.9.",t_ventas2019, startCol = 1,startRow = 16,colNames = F) ##escribir
addStyle(wb498,"2.1.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb498,"2.1.9.",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
tabulado498 <- saveWorkbook(wb498,"Tabulados_DIEE_2021.xlsx",overwrite = T)

    #VENTAS NACIONALES#
    t_vntnacional2019 <- d_dieeap8 %>% summarise ("total_ventas"=sum((ventas_nacionales/150.402318656309)*100,na.rm=T))
    t_vntnacional19<- t_vntnacional2019 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_13_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_13_1,sheet = "2.1.9.",t_vntnacional19, startCol = 3,startRow = 16,colNames = F) ##escribir
    tabulado4_13_1 <- saveWorkbook(wb4_13_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2019 <- d_dieeap8 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/150.402318656309)*100,na.rm=T))
    t_export19 <- t_export2019 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_13_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_13_2,sheet = "2.1.9.",t_export19, startCol = 4,startRow = 16,colNames = F) ##escribir
    tabulado4_13_2 <- saveWorkbook(wb4_13_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2020
    bd_dieeap9 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
    d_dieeap9 <- bd_dieeap9 %>% filter (anio == 2020 & situacion == 1 & estructura_estrat==1)
    t_ventas2020 <- d_dieeap9 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/149.802064061692)*100,na.rm=T))
    
    #Exportar resultados a excel
    wb4108<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4108,sheet = "2.1.9.",t_ventas2020, startCol = 1,startRow = 17,colNames = F) ##escribir
    addStyle(wb4108,"2.1.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
    addStyle(wb4108,"2.1.9.",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
    tabulado4108 <- saveWorkbook(wb4108,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #VENTAS NACIONALES#
    t_vntnacional2020 <- d_dieeap9 %>% summarise ("total_ventas"=sum((ventas_nacionales/149.802064061692)*100,na.rm=T))
    t_vntnacional20<- t_vntnacional2020 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_14_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_14_1,sheet = "2.1.9.",t_vntnacional20, startCol = 3,startRow = 17,colNames = F) ##escribir
    tabulado4_14_1 <- saveWorkbook(wb4_14_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2020 <- d_dieeap9 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/149.802064061692)*100,na.rm=T))
    t_export20 <- t_export2020 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_14_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_14_2,sheet = "2.1.9.",t_export20, startCol = 4,startRow = 17,colNames = F) ##escribir
    tabulado4_14_2 <- saveWorkbook(wb4_14_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)
  
#lectura de base 2021
    bd_dieeap10 <- bd_diee %>% select(ventas_totales,anio,situacion,estructura_estrat,ventas_nacionales,exportaciones_netas)
    d_dieeap10 <- bd_dieeap10 %>% filter (anio == 2021 & situacion == 1 & estructura_estrat==1)
    t_ventas2021 <- d_dieeap10 %>% group_by(anio) %>% summarise ("total_ventas"=sum((ventas_totales/153.665955040775)*100,na.rm=T))
    
    #Exportar resultados a excel
    wb4109<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4109,sheet = "2.1.9.",t_ventas2021, startCol = 1,startRow = 18,colNames = F) ##escribir
    addStyle(wb4109,"2.1.9.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
    addStyle(wb4109,"2.1.9.",grisStyle,cols= 1:4, rows = 7,gridExpand = TRUE,stack=TRUE)
    tabulado4109 <- saveWorkbook(wb4109,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #VENTAS NACIONALES#
    t_vntnacional2021 <- d_dieeap10 %>% summarise ("total_ventas"=sum((ventas_nacionales/153.665955040775)*100,na.rm=T))
    t_vntnacional21<- t_vntnacional2021 %>% select(total_ventas)
    
    #Exportar resultados a excel
    wb4_15_1<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_15_1,sheet = "2.1.9.",t_vntnacional21, startCol = 3,startRow = 18,colNames = F) ##escribir
    tabulado4_15_1 <- saveWorkbook(wb4_15_1,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
    #EXPORTACIONES#
    t_export2021 <- d_dieeap10 %>% summarise ("total_exportaciones"=sum((exportaciones_netas/153.665955040775)*100,na.rm=T))
    t_export21 <- t_export2021 %>% select(total_exportaciones)
    
    #Exportar resultados a excel
    wb4_15_2<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
    writeData(wb4_15_2,sheet = "2.1.9.",t_export21, startCol = 4,startRow = 18,colNames = F) ##escribir
    tabulado4_15_2 <- saveWorkbook(wb4_15_2,"Tabulados_DIEE_2021.xlsx",overwrite = T)
    
################################TABULADO 2.1.10############################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                       ANIO 2021 POR FORMA INSTITUCIONAL                             #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,ventas_totales,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables
t_seccventas <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccventas$total_ventas,na.rm =T )
t_seccventas$porcentaje <- t_seccventas$total_ventas / total

#Lectura catalogo de variables.
des_seccventas <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccventas,t_seccventas,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb50<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb50,sheet = "2.1.10.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb50,sheet = "2.1.10.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb50,sheet = "2.1.10.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb50,sheet = "2.1.10.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb50,"2.1.10.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb50,"2.1.10.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado50 <- saveWorkbook(wb50,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#################################TABULADO 2.1.11###########################################
# VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS#
#                ANIO 2021 POR TAMANO DE  EMPRESA                                     #

#seleccion de variables###
bd_tamano <- bd_diee %>% select(tamanoe_plazas,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_tamanovp <- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise ("total_vp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanovp$total_vp,na.rm =T )
t_tamanovp$porcentaje <- t_tamanovp$total_vp/ total

#Lectura catalogo de variables.
des_tamanovp <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanovp,t_tamanovp,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb51<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb51,sheet = "2.1.11.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb51,sheet = "2.1.11.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb51,sheet = "2.1.11.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb51,sheet = "2.1.11.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb51,"2.1.11.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb51,"2.1.11.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb51,"2.1.11.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb51,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#################################TABULADO 2.1.12###########################################
# VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS#
#                ANIO 2021 POR TAMANO DE  EMPRESA (COP)                               #

#seleccion de variables###
bd_tamano <- bd_diee %>% select(tamano_cop,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_tamanovp <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_vp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_tamanovp$total_vp,na.rm =T )
t_tamanovp$porcentaje <- t_tamanovp$total_vp/ total

#Lectura catalogo de variables.
des_tamanovp <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanovp,t_tamanovp,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb52<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb52,sheet = "2.1.12.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb52,sheet = "2.1.12.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb52,sheet = "2.1.12.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb52,sheet = "2.1.12.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb52,"2.1.12.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb52,"2.1.12.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb52,"2.1.12.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb52,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb52)

##################TABULADO 2.1.13##########################################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                   ANIO 2021 POR SECTOR ECONOMICO                                    #

#seleccion de variables
bd_tamano <- bd_diee %>% select(gsectores,ventas_totales,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_sectoresvp <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_secvp"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_sectoresvp$total_secvp,na.rm =T )
t_sectoresvp$porcentaje <- t_sectoresvp$total_secvp/ total

#Lectura catalogo de variables.
des_sectoresvp <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectoresvp,t_sectoresvp,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_secvp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb53<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb53,sheet = "2.1.13.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb53,sheet = "2.1.13.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb53,sheet = "2.1.13.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb53,sheet = "2.1.13.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb53,"2.1.13.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb53,"2.1.13.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb53,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##########################TABULADO 2.1.14##################################################
#VENTAS TOTALES SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#                       ANIO 2021, POR ACTIVIDAD ECONOMICA                            # 

#seleccion de variables###
bd_tamano <- bd_diee %>% select(codigo_seccion,ventas_totales,estructura_estrat,anio,situacion)
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_seccap <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_seccap$total_ventas,na.rm =T )
t_seccap$porcentaje <- t_seccap$total_ventas / total

#Lectura catalogo de variables.
des_seccap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_seccap,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb54<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb54,sheet = "2.1.14.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb54,sheet = "2.1.14.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb54,sheet = "2.1.14.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb54,sheet = "2.1.14.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb54,"2.1.14.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb54,"2.1.14.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb54,"Tabulados_DIEE_2021.xlsx",overwrite = T)

################################TABULADO 2.1.15##########################################
#VENTAS TOTALES SEGUN PARTICIPACION NACIONAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #
#                ANIO 2021 POR PROVINCIA                                            #

df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,ventas_totales,estructura_estrat,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_ventas"=sum(ventas_totales,na.rm=T), porcentaje = 0)
total <- sum(t_provap$total_ventas,na.rm =T )
t_provap$porcentaje <- t_provap$total_ventas / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_ventas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb55 <-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb55,sheet = "2.1.15.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb55,sheet = "2.1.15.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb55,sheet = "2.1.15.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb55,sheet = "2.1.15.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb55,"2.1.15.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb55,"2.1.15.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb55,"Tabulados_DIEE_2021.xlsx",overwrite = T)

########################TABULADO 2.1.16#################################
#PLAZAS DE EMPEO REGISTRADO (EMPRESAS CON ACTIVIDADES PRODUCTIVAS) #                  
#                   PERIODO 2011 - 2021 POR ANIO                   #

#######PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE) PERIODO 2006-2011

d_plazas <- bd_diee1 %>% select(estructura_estrat,plazas_equiv,plazas_equiv_hombres,plazas_equiv_mujeres,anio,situacion)
bd_plazas <- d_plazas %>% filter(anio == 2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2021#
t_plazas <- bd_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T),
                                                       "total_plazashombres" =sum(plazas_equiv_hombres,na.rm=T),
                                                       "total_plazasmujeres"=sum(plazas_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb56<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb56,sheet = "2.1.16.",t_plazas, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb56,"2.1.16.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb56,"2.1.16.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb56,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2021 POR ANIO

d_plazas <- bd_diee %>% select(estructura_estrat,plazas_equiv,plazas_equiv_hombres,plazas_equiv_mujeres,anio,situacion)
bd_plazas <- d_plazas %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2021#
t_plazas <- bd_plazas %>% group_by(anio) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T),
                                                       "total_plazashombres" =sum(plazas_equiv_hombres,na.rm=T),
                                                       "total_plazasmujeres"=sum(plazas_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb561<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb561,sheet = "2.1.16.",t_plazas, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb561,"2.1.16.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb561,"2.1.16.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb561,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################################TABULADO 2.1.17#############################
#    PLAZAS DE EMPLEO REGISTRADO SEG?N PARTICIPACI?N EN EL TOTAL           #
#    (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), A?O 2021 POR RANGO DE EDAD    #

bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1 )

#seleccion de variables
bd_plazasrp <- bd_dieeact %>% select(plazas_rango_edad_1,plazas_rango_edad_2,
                                    plazas_rango_edad_3,plazas_rango_edad_4, 
                                    plazas_rango_edad_5,estructura_estrat,
                                    anio,situacion)


#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_plazasrp %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_plazasre1 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_1,na.rm=T), porcentaje = 0)
t_plazasre2 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_2,na.rm=T), porcentaje = 0)
t_plazasre3 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_3,na.rm=T), porcentaje = 0)
t_plazasre4 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_4,na.rm=T), porcentaje = 0)
t_plazasre5 <- bd_plazasrp %>% summarise ("total_plazas"=sum(plazas_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangos1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_plazasre1))
t_rangos2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_plazasre2))
t_rangos3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_plazasre3))
t_rangos4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_plazasre4))
t_rangos5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_plazasre5))

tabla1 <- data.frame (rbind(t_rangos1,t_rangos2,t_rangos3, t_rangos4, t_rangos5))
total <- sum(tabla1$total_plazas,na.rm = T)
tabla1$porcentaje <- tabla1$total_plazas/total

#Exportar resultados a excel
wb57<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb57,sheet = "2.1.17.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb57,sheet = "2.1.17.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb57,sheet = "2.1.17.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb57,sheet = "2.1.17.",tabla1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb57,"2.1.17.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb57,"2.1.17.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb57,"2.1.17.",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb57,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################################TABULADO 2.1.18#############################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL          #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR FORMA INSTITUCIONAL#

#seleccion de variables###
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,plazas_equiv,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_plazasins <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_plazasins$total_plazas,na.rm =T )
t_plazasins$porcentaje <- t_plazasins$total_plazas / total

#Lectura catalogo de variables.
des_plazasinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_plazasinst,t_plazasins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb58<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb58,sheet = "2.1.18.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb58,sheet = "2.1.18.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb58,sheet = "2.1.18.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb58,sheet = "2.1.18.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb58,"2.1.18.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb58,"2.1.18.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb58,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#################################TABULADO 2.1.19###############################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL         #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR TAMANO DE EMPRESA #

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamanoe_plazas,plazas_equiv,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_tamanoplazas <- bd_dieeact %>% group_by(tamanoe_plazas) %>% summarise ("total_vp"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoplazas$total_vp,na.rm =T )
t_tamanoplazas$porcentaje <- t_tamanoplazas$total_vp/ total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanoplazas,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb59<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb59,sheet = "2.1.19.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb59,sheet = "2.1.19.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb59,sheet = "2.1.19.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb59,sheet = "2.1.19.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb59,"2.1.19.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb59,"2.1.19.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb59,"2.1.19.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb59,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#################################TABULADO 2.1.20#####################################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL               #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR TAMANO DE EMPRESA (COP) #

#seleccion de variables
bd_tamano <- bd_diee %>% select(tamano_cop,plazas_equiv,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables
t_tamanocop <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_vp"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamanocop$total_vp,na.rm =T )
t_tamanocop$porcentaje <- t_tamanocop$total_vp/ total

#Lectura catalogo de variables.
des_tamanoplazas <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoplazas,t_tamanocop,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_vp,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb60<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb60,sheet = "2.1.20.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb60,sheet = "2.1.20.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb60,sheet = "2.1.20.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb60,sheet = "2.1.20.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb60,"2.1.20.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb60,"2.1.20.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb60,"2.1.20.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb60,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb60)

#########################TABULADO 2.1.21######################################
#       PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL       #
#(EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR SECTOR ECONOMICO  #

#seleccion de variables
bd_sector <- bd_diee %>% select(gsectores,plazas_equiv,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_sector %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_sectoresvp <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_sectoresvp$total_plazas,na.rm =T )
t_sectoresvp$porcentaje <- t_sectoresvp$total_plazas/ total

#Lectura catalogo de variables.
des_sectoresvp <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectoresvp,t_sectoresvp,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))
v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb61<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb61,sheet = "2.1.21.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb61,sheet = "2.1.21.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb61,sheet = "2.1.21.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb61,sheet = "2.1.21.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb61,"2.1.21.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb61,"2.1.21.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb61,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##############################TABULADO 2.1.22##################################
#   PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL            #
#(EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR ACTIVIDAD ECONOMICA#

#seleccion de variables###
bd_act <- bd_diee %>% select(codigo_seccion,plazas_equiv,estructura_estrat,anio,situacion)
bd_dieeact <- bd_act %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_secact <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_secact$total_plazas,na.rm =T )
t_secact$porcentaje <- t_secact$total_plazas / total

#Lectura catalogo de variables.
des_secact <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccap,t_secact,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb62<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb62,sheet = "2.1.22.","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb62,sheet = "2.1.22.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb62,sheet = "2.1.22.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb62,sheet = "2.1.22.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb62,"2.1.22.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb62,"2.1.22.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb62,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.23######################################
#      PLAZAS DE EMPEO REGISTRADO SEGUN PARTICIPACION NACIONAL      #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR PROVINCIA   #

df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,plazas_equiv,estructura_estrat,anio,situacion)
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provap <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_plazas"=sum(plazas_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_provap$total_plazas,na.rm =T )
t_provap$porcentaje <- t_provap$total_plazas / total

#Lectura catalogo de variables.
des_provap <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provap,t_provap,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_plazas,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb63 <-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb63,sheet = "2.1.23.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb63,sheet = "2.1.23.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb63,sheet = "2.1.23.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb63,sheet = "2.1.23.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb63,"2.1.23.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb63,"2.1.23.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb63,"Tabulados_DIEE_2021.xlsx",overwrite = T)

######################## TABULADO 2.1.24 ##########################################
#EMPLEO REGISTRADO (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2021#

# EMPLEO (UNIVERSO DIEE) PERIODO 2006-2011
#Seleccion de variables que se requieren para el tabulado.
d_empleo <- bd_diee1 %>% select(estructura_estrat,empleo_equiv,empleo_equiv_hombres,empleo_equiv_mujeres,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_empleo <- d_empleo %>% filter(anio == 2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2021#
t_empleo <- bd_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T),
                                                        "total_empleohombres" =sum(empleo_equiv_hombres,na.rm=T),
                                                        "total_empleomujeres"=sum(empleo_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb64<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb64,sheet = "2.1.24.",t_empleo, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb64,"2.1.24.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb64,"2.1.24.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb64,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#PLAZAS DE EMPEO REGISTRADO (UNIVERSO DIEE), PERIODO 2012 - 2021 POR ANIO

d_empleo <- bd_diee %>% select(estructura_estrat,empleo_equiv,empleo_equiv_hombres,empleo_equiv_mujeres,anio,situacion)
bd_empleo <- d_empleo %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2021#
t_empleo <- bd_empleo %>% group_by(anio) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T),
                                                        "total_empleohombres" =sum(empleo_equiv_hombres,na.rm=T),
                                                        "total_empleomujeres"=sum(empleo_equiv_mujeres,na.rm=T))

#Exportar resultados a excel
wb641<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb641,sheet = "2.1.24.",t_empleo, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb641,"2.1.24.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb641,"2.1.24.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb641,"Tabulados_DIEE_2021.xlsx",overwrite = T)

############TABULADO 2.1.25#####################################################
#     EMPLEO REGISTRADO SEG?N PARTICIPACI?N EN EL TOTAL                    #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), A?O 2021 POR RANGO DE EDAD       #
bd_dieeact <- bd_diee%>% filter(anio == 2021 & situacion==1 )
#seleccion de variables
bd_empleorp <- bd_dieeact %>% select(empleo_rango_edad_1,empleo_rango_edad_2,
                                    empleo_rango_edad_3,empleo_rango_edad_4, 
                                    empleo_rango_edad_5,estructura_estrat,
                                    anio,situacion)

#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact1 <- bd_empleorp %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_empleore1 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_1,na.rm=T), porcentaje = 0)
t_empleore2 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_2,na.rm=T), porcentaje = 0)
t_empleore3 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_3,na.rm=T), porcentaje = 0)
t_empleore4 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_4,na.rm=T), porcentaje = 0)
t_empleore5 <- bd_dieeact1 %>% summarise ("total_empleo"=sum(empleo_rango_edad_5,na.rm=T), porcentaje = 0)

t_rangose1 = data.frame(new.row.names = "RANGO DE EDAD 1", rbind(t_empleore1))
t_rangose2 = data.frame(new.row.names = "RANGO DE EDAD 2", rbind(t_empleore2))
t_rangose3 = data.frame(new.row.names = "RANGO DE EDAD 3", rbind(t_empleore3))
t_rangose4 = data.frame(new.row.names = "RANGO DE EDAD 4", rbind(t_empleore4))
t_rangose5 = data.frame(new.row.names = "RANGO DE EDAD 5", rbind(t_empleore5))

tablae1 <- data.frame (rbind(t_rangose1,t_rangose2,t_rangose3, t_rangose4, t_rangose5))
total <- sum(tablae1$total_empleo,na.rm = T)
tablae1$porcentaje <- tablae1$total_empleo/total
v_total <- c("TOTAL",total,"100.00%")
v_total <- matrix(v_total,nrow=1,ncol=3)

#Exportar resultados a excel
wb65<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb65,sheet = "2.1.25." ,v_total,startCol = 1,startRow = 7,colNames = F)
writeData(wb65,sheet = "2.1.25.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb65,sheet = "2.1.25.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb65,sheet = "2.1.25.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb65,sheet = "2.1.25.",tablae1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb65,"2.1.25.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb65,"2.1.25.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb65,"2.1.25.",grisStyle,cols= 6:7, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb65,"Tabulados_DIEE_2021.xlsx",overwrite = T)

############TABULADO 2.1.26#####################################################
#      EMPLEO REGISTRADO SEGUN PARTICIPACION EN EL TOTAL                   #
# (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021 POR FORMA INSTITUCIONAL#

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_seccion,estructura_estrat,forma_institucional,empleo_equiv,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#Calculo de las variables.
t_empleoins <- bd_dieeact %>% group_by(forma_institucional) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_empleoins$total_empleo,na.rm =T )
t_empleoins$porcentaje <- t_empleoins$total_empleo / total

#Lectura catalogo de variables.
des_empleoinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_empleoinst,t_empleoins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb66 <-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb66,sheet = "2.1.26.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb66,sheet = "2.1.26.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb66,sheet = "2.1.26.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb66,sheet = "2.1.26.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb66,"2.1.26.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb66,"2.1.26.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb66,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.27################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2021POR TAMANO DE EMPRESA                                 #

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamanoe_empleo,empleo_equiv,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_tamanoempleo <- bd_dieeact %>% group_by(tamanoe_empleo) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoempleo$total_empleo,na.rm =T )
t_tamanoempleo$porcentaje <- t_tamanoempleo$total_empleo/ total

#Lectura catalogo de variables.
des_tamanoempleo <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoempleo,t_tamanoempleo,by.x = "CODIGO",by.y = "tamanoe_empleo",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb67<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb67,sheet = "2.1.27.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb67,sheet = "2.1.27.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb67,sheet = "2.1.27.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb67,sheet = "2.1.27.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb67,"2.1.27.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb67,"2.1.27.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb67,"2.1.27.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb67,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.28################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#              ANIO 2021POR TAMANO DE EMPRESA  (COP)                          #

#Seleccion de variables que se requieren para el tabulado.
bd_tamano <- bd_diee %>% select(tamano_cop,empleo_equiv,estructura_estrat,codigo_seccion,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_tamano %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#Calculo de las variables.
t_tamanocop <- bd_dieeact %>% group_by(tamano_cop) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_tamanocop$total_empleo,na.rm =T )
t_tamanocop$porcentaje <- t_tamanocop$total_empleo/ total

#Lectura catalogo de variables.
des_tamanocop <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanocop,t_tamanocop,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb68<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb68,sheet = "2.1.28.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb68,sheet = "2.1.28.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb68,sheet = "2.1.28.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb68,sheet = "2.1.28.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb68,"2.1.28.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb68,"2.1.28.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb68,"2.1.28.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb68,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb68)

##############TABULADO 2.1.29######################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS)#
#            ANIO 2021 POR SECTOR ECONOMICO                                   #     

#seleccion de variables###
bd_sector <- bd_diee %>% select(gsectores,empleo_equiv,estructura_estrat,codigo_seccion,anio,situacion)
bd_dieeact <- bd_sector %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_sectorempleo <- bd_dieeact %>% group_by(gsectores) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_sectorempleo$total_empleo,na.rm =T )
t_sectorempleo$porcentaje <- t_sectorempleo$total_empleo/ total

#Lectura catalogo de variables.
des_sectorempleo <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorempleo,t_sectorempleo,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb69<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb69,sheet = "2.1.29.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb69,sheet = "2.1.29.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb69,sheet = "2.1.29.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb69,sheet = "2.1.29.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb69,"2.1.29.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb69,"2.1.29.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb69,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#################TABULADO 2.1.30##############################################################
#EMPLEO SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021#
#                    POR ACTIVIDAD ECONOMICA                                             #

#seleccion de variables###
bd_act <- bd_diee %>% select(codigo_seccion,empleo_equiv,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- bd_act %>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_secact <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_secact$total_empleo,na.rm =T )
t_secact$porcentaje <- t_secact$total_empleo / total

#Lectura catalogo de variables.
des_secact <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_secact,t_secact,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb70<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb70,sheet = "2.1.30.","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb70,sheet = "2.1.30.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb70,sheet = "2.1.30.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb70,sheet = "2.1.30.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb70,"2.1.30.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb70,"2.1.30.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb70,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.31#########################################################
##EMPLEO SEGUN PARTICIPACION NACIONAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021#
#                                POR PROVINCIA                                         #

#Seleccion de variables que se requieren para el tabulado.
df1 <- bd_diee %>% select(codigo_provincia,codigo_seccion,empleo_equiv,estructura_estrat,anio,situacion)
#Filtrar empresas activas del año del cual se requiere realizar la validación.
bd_dieeact <- df1 %>% filter(anio == 2021 & situacion==1 & estructura_estrat ==1)

#calculo#
t_provempleo <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_empleo"=sum(empleo_equiv,na.rm=T), porcentaje = 0)
total <- sum(t_provempleo$total_empleo,na.rm =T )
t_provempleo$porcentaje <- t_provempleo$total_empleo / total

#Lectura catalogo de variables.
des_provempleo <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provempleo,t_provempleo,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_empleo,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb71 <-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb71,sheet = "2.1.31.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb71,sheet = "2.1.31.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb71,sheet = "2.1.31.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb71,sheet = "2.1.31.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb71,"2.1.31.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb71,"2.1.31.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb71,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.32#############################################
##MASA SALARIAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), PERIODO 2011 - 2021#
#                          POR ANIO                                        #

##BASE GENERAL 2011
d_remuneracion1 <- bd_diee1 %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
bd_dieeact1 <- bd_diee1 %>% filter(anio==2011 & situacion==1 & estructura_estrat ==1)

#total empresas del año 2006-2011
t_remuneraciones1 <- bd_dieeact1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb72<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb72,sheet = "2.1.32.",t_remuneraciones1, startCol = 1,startRow = 7,colNames = F) ##escribir
addStyle(wb72,"2.1.32.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb72,"2.1.32.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb72,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##BASE GENERAL 2012-2021
d_remuneracion <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
bd_dieeact <- d_remuneracion %>% filter(situacion==1 & estructura_estrat ==1)

#total empresas del año 2012-2021
t_remuneraciones <- bd_dieeact %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T),
                                                                     "total_remuneracioneshombres" =sum(remuneraciones_hombres,na.rm=T),
                                                                     "total_remuneracionesmujeres"=sum(remuneraciones_mujeres,na.rm=T))

#Exportar resultados a excel
wb721<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb721,sheet = "2.1.32.",t_remuneraciones, startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb721,"2.1.32.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb721,"2.1.32.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb721,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.33: CONSTANTE#################
#           MASA SALARIAL CONSTANTE            #

#lectura de base 2011
bd_dieemsc <- bd_diee1 %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc <- bd_dieemsc %>% filter (anio == 2011 & situacion == 1& estructura_estrat ==1)
t_masa2011 <- d_dieemsc %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/123.6463878309520)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/123.6463878309520)*100,na.rm=T))
#Exportar resultados a excel
wb732<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb732,sheet = "2.1.33.",t_masa2011, startCol = 1,startRow = 7,colNames = F) ##escribir
tabulado732 <- saveWorkbook(wb732,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2012
bd_dieemsc1 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc1 <- bd_dieemsc1 %>% filter (anio == 2012 & situacion == 1 & estructura_estrat ==1)
t_masa2012 <- d_dieemsc1 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/128.7949116563170)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/128.7949116563170)*100,na.rm=T))
#Exportar resultados a excel
wb733<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb733,sheet = "2.1.33.",t_masa2012, startCol = 1,startRow = 8,colNames = F) ##escribir
tabulado733 <- saveWorkbook(wb733,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2013
bd_dieemsc2 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc2 <- bd_dieemsc2 %>% filter (anio == 2013 & situacion == 1 & estructura_estrat ==1)
t_masa2013 <- d_dieemsc2 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/132.2728147645030)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/132.2728147645030)*100,na.rm=T))
#Exportar resultados a excel
wb734<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb734,sheet = "2.1.33.",t_masa2013, startCol = 1,startRow = 9,colNames = F) ##escribir
tabulado734 <- saveWorkbook(wb734,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2014
bd_dieemsc3 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc3 <- bd_dieemsc3 %>% filter (anio == 2014 & situacion == 1 & estructura_estrat ==1)
t_masa2014 <- d_dieemsc3 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracioneshombres" =sum((remuneraciones_hombres/137.1237313761930)*100,na.rm=T),
                                                          "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/137.1237313761930)*100,na.rm=T))
#Exportar resultados a excel
wb735<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb735,sheet = "2.1.33.",t_masa2014, startCol = 1,startRow = 10,colNames = F) ##escribir
tabulado735 <- saveWorkbook(wb735,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2015
bd_dieemsc4 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc4 <- bd_dieemsc4 %>% filter (anio == 2015 & situacion == 1 & estructura_estrat ==1)
t_masa2015 <- d_dieemsc4 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/141.7586850842260)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/141.7586850842260)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/141.7586850842260)*100,na.rm=T))
#Exportar resultados a excel
wb736<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb736,sheet = "2.1.33.",t_masa2015, startCol = 1,startRow = 11,colNames = F) ##escribir
tabulado736 <- saveWorkbook(wb736,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2016
bd_dieemsc5 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc5 <- bd_dieemsc5 %>% filter (anio == 2016 & situacion == 1 & estructura_estrat ==1)
t_masa2016 <- d_dieemsc5 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.3460867154060)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.3460867154060)*100,na.rm=T))
#Exportar resultados a excel
wb737<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb737,sheet = "2.1.33.",t_masa2016, startCol = 1,startRow = 12,colNames = F) ##escribir
tabulado737 <- saveWorkbook(wb737,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2017
bd_dieemsc6 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc6 <- bd_dieemsc6 %>% filter (anio == 2017 & situacion == 1 & estructura_estrat ==1)
t_masa2017 <- d_dieemsc6 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.0641241843250)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.0641241843250)*100,na.rm=T))
#Exportar resultados a excel
wb738<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb738,sheet = "2.1.33.",t_masa2017, startCol = 1,startRow = 13,colNames = F) ##escribir
addStyle(wb738,"2.1.33.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb738,"2.1.33.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado738 <- saveWorkbook(wb738,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2018
bd_dieemsc8 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc8 <- bd_dieemsc8 %>% filter (anio == 2018 & situacion == 1 & estructura_estrat ==1)
t_masa2018 <- d_dieemsc8 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.444918475971)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.444918475971)*100,na.rm=T))
#Exportar resultados a excel
wb739<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb739,sheet = "2.1.33.",t_masa2018, startCol = 1,startRow = 14,colNames = F) ##escribir
addStyle(wb739,"2.1.33.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb739,"2.1.33.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado738 <- saveWorkbook(wb739,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2019
bd_dieemsc9 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc9 <- bd_dieemsc9 %>% filter (anio == 2019 & situacion == 1 & estructura_estrat ==1)
t_masa2019 <- d_dieemsc9 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/143.344842799337)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/143.344842799337)*100,na.rm=T))
#Exportar resultados a excel
wb7310<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb7310,sheet = "2.1.33.",t_masa2019, startCol = 1,startRow = 15,colNames = F) ##escribir
addStyle(wb7310,"2.1.33.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb7310,"2.1.33.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado7310 <- saveWorkbook(wb7310,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2020
bd_dieemsc10 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc10 <- bd_dieemsc10 %>% filter (anio == 2020 & situacion == 1 & estructura_estrat ==1)
t_masa2020 <- d_dieemsc10 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/142.009628029416)*100,na.rm=T),
                                                           "total_remuneracioneshombres" =sum((remuneraciones_hombres/142.009628029416)*100,na.rm=T),
                                                           "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/142.009628029416)*100,na.rm=T))
#Exportar resultados a excel
wb7311<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb7311,sheet = "2.1.33.",t_masa2020, startCol = 1,startRow = 16,colNames = F) ##escribir
addStyle(wb7311,"2.1.33.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb7311,"2.1.33.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado7311 <- saveWorkbook(wb7311,"Tabulados_DIEE_2021.xlsx",overwrite = T)

#lectura de base 2021
bd_dieemsc11 <- bd_diee %>% select(estructura_estrat,remuneraciones,remuneraciones_hombres,remuneraciones_mujeres,anio,situacion)
d_dieemsc11 <- bd_dieemsc11 %>% filter (anio == 2021 & situacion == 1 & estructura_estrat ==1)
t_masa2021 <- d_dieemsc11 %>% group_by(anio) %>% summarise ("total_remuneraciones"=sum((remuneraciones/144.775430052823)*100,na.rm=T),
                                                            "total_remuneracioneshombres" =sum((remuneraciones_hombres/144.775430052823)*100,na.rm=T),
                                                            "total_remuneracionesmujeres"=sum((remuneraciones_mujeres/144.775430052823)*100,na.rm=T))
#Exportar resultados a excel
wb7312<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb7312,sheet = "2.1.33.",t_masa2021, startCol = 1,startRow = 17,colNames = F) ##escribir
addStyle(wb7312,"2.1.33.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb7312,"2.1.33.",grisStyle,cols= 1:4, rows = 6,gridExpand = TRUE,stack=TRUE)
tabulado7312 <- saveWorkbook(wb7312,"Tabulados_DIEE_2021.xlsx",overwrite = T)

####################TABULADO 2.1.34###################################################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021#
#               POR FORMA INSTITUCIONAL                                                          #

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,forma_institucional,situacion, estructura_estrat)
bd_dieems <- bd_remuneraciones%>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_remuneracionesins <- bd_dieems %>% group_by(forma_institucional) %>% summarise ("total_remuneraciones"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_remuneracionesins$total_remuneraciones,na.rm =T )
t_remuneracionesins$porcentaje <- t_remuneracionesins$total_remuneraciones / total

#Lectura catalogo de variables.
des_remuneracionesinst <- read.xlsx("diee_catologo.xlsx", sheet = "forma_institucional")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_remuneracionesinst,t_remuneracionesins,by.x = "CODIGO",by.y = "forma_institucional",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remuneraciones,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb74<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb74,sheet = "2.1.34.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb74,sheet = "2.1.34.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb74,sheet = "2.1.34.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb74,sheet = "2.1.34.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb74,"2.1.34.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb74,"2.1.34.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb74,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###################TABULADO 2.1.35###################################################################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021#
#             POR TAMANO DE EMPRESA                                                             #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,tamanoe_plazas,situacion, estructura_estrat)
bd_dieetam <- bd_diee%>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)
      
#calculo#
t_tamanoremu <- bd_dieetam %>% group_by(tamanoe_plazas) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamanoe_plazas",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb75<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb75,sheet = "2.1.35.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb75,sheet = "2.1.35.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb75,sheet = "2.1.35.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb75,sheet = "2.1.35.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb75,"2.1.35.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb75,"2.1.35.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb75,"2.1.35.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb75,"Tabulados_DIEE_2021.xlsx",overwrite = T)

###################TABULADO 2.1.36###################################################################
#MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021#
#             POR TAMANO DE EMPRESA   (COP)                                                     #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,tamano_cop,situacion, estructura_estrat)
bd_dieetam <- bd_diee%>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_tamanoremu <- bd_dieetam %>% group_by(tamano_cop) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_tamanoremu$total_remu,na.rm =T )
t_tamanoremu$porcentaje <- t_tamanoremu$total_remu / total

#Lectura catalogo de variables.
des_tamanoremu <- read.xlsx("diee_catologo.xlsx", sheet = "tamano_cop")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_tamanoremu,t_tamanoremu,by.x = "CODIGO",by.y = "tamano_cop",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb76<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb76,sheet = "2.1.36.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb76,sheet = "2.1.36.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb76,sheet = "2.1.36.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb76,sheet = "2.1.36.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb76,"2.1.36.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb76,"2.1.36.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
addStyle(wb76,"2.1.36.",grisStyle,cols= 6:8, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb76,"Tabulados_DIEE_2021.xlsx",overwrite = T)
rm(wb76)

#######################TABULADO 2.1.37################################################################
#"MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (EMPRESAS CON ACTIVIDADES PRODUCTIVAS), ANIO 2021#
#                   POR SECTOR ECONOMICO                                                         #

bd_remuneraciones <- bd_diee %>% select(remuneraciones,gsectores,situacion, estructura_estrat)
bd_dieese <- bd_diee%>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_sectorremu<- bd_dieese %>% group_by(gsectores) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_sectorremu$total_remu,na.rm =T )
t_sectorremu$porcentaje <- t_sectorremu$total_remu / total

#Lectura catalogo de variables.
des_sectorremu <- read.xlsx("diee_catologo.xlsx", sheet = "g_sectores")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_sectorremu,t_sectorremu,by.x = "CODIGO",by.y = "gsectores",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb77<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb77,sheet = "2.1.37.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb77,sheet = "2.1.37.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb77,sheet = "2.1.37.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb77,sheet = "2.1.37.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb77,"2.1.37.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb77,"2.1.37.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb77,"Tabulados_DIEE_2021.xlsx",overwrite = T)

############TABULADO 2.1.38####################################################
# MASA SALARIAL SEGUN PARTICIPACION EN EL TOTAL (UNIVERSO DIEE), ANIO 2021#
#       POR ACTIVIDAD ECONOMICA                                           #  

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,codigo_seccion,situacion, estructura_estrat)
bd_dieeact <- bd_remuneraciones%>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_seccre <- bd_dieeact %>% group_by(codigo_seccion) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_seccre$total_remu,na.rm =T )
t_seccre$porcentaje <- t_seccre$total_remu / total

#Lectura catalogo de variables.
des_seccre <- read.xlsx("diee_catologo.xlsx", sheet = "cod_ciiu4_seccion")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_seccre,t_seccre,by.x = "CODIGO",by.y = "codigo_seccion",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb78<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb78,sheet = "2.1.38.","TOTAL", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb78,sheet = "2.1.38.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb78,sheet = "2.1.38.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb78,sheet = "2.1.38.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb78,"2.1.38.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb78,"2.1.38.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb78,"Tabulados_DIEE_2021.xlsx",overwrite = T)

##########TABULADO 2.1.39################################################################
#MASA SALARIAL SEGUN PARTICIPACION NACIONAL (UNIVERSO DIEE), ANIO 2021 POR PROVINCIA#

bd_remuneraciones <- bd_diee %>% select(anio,remuneraciones,codigo_provincia,situacion, estructura_estrat)
bd_dieeact <- bd_remuneraciones%>% filter(anio == 2021 & situacion==1 & estructura_estrat==1)

#calculo#
t_provre <- bd_dieeact %>% group_by(codigo_provincia) %>% summarise ("total_remu"=sum(remuneraciones,na.rm=T), porcentaje = 0)
total <- sum(t_provre$total_remu,na.rm =T )
t_provre$porcentaje <- t_provre$total_remu / total
 
#Lectura catalogo de variables.
des_provre <- read.xlsx("diee_catologo.xlsx", sheet = "cod_provincia")

#Para unir identificadores y descripciones de excel
dft2 <-merge(des_provre,t_provre,by.x = "CODIGO",by.y = "codigo_provincia",all.y = T)
dft3 <- dft2 %>% select(DESCRIPCION,total_remu,porcentaje)
t_estrato1 <- arrange(dft3,(desc(porcentaje)))

#Exportar resultados a excel
wb79<-loadWorkbook(file = "Tabulados_DIEE_2021.xlsx")
writeData(wb79,sheet = "2.1.39.","Total", startCol = 1,startRow = 7, colNames = F) ##escribir
writeData(wb79,sheet = "2.1.39.",total, startCol = 2,startRow = 7, colNames = F)
writeData(wb79,sheet = "2.1.39.",1, startCol = 3,startRow = 7, colNames = F)
writeData(wb79,sheet = "2.1.39.",t_estrato1,startCol = 1,startRow = 8,colNames = F) ##escribir
addStyle(wb79,"2.1.39.",newStyle,cols= 1:100, rows = 1:100,gridExpand = TRUE,stack=TRUE)
addStyle(wb79,"2.1.39.",grisStyle,cols= 1:3, rows = 6,gridExpand = TRUE,stack=TRUE)
saveWorkbook(wb79,"Tabulados_DIEE_2021.xlsx",overwrite = T)
